#!/bin/bash
# #############################################################################
# SilentInstall.sh
#
#     Licensed Materials - Property of IBM
#    "Restricted Materials of IBM"
#
#    5724-U38, 5724-U39, 5724-U48
#
#     Copyright IBM Corp. 2008, 2021 All Rights Reserved
#
#     Copyright 2014, 2021 UNICOM Systems, Inc. - All Rights Reserved
#
#    US Government Users Restricted Rights - Use, duplication or
#    disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# UNIX shell script to silently install and/or uninstall the Optim components:
# Optim Runtime Services, Optim Web Applications.  It can also uninstall
# WebSphere Application Server Community Edition (WAS-CE) (11.3.0.8 only).
#
# Refer to optimutil.sh for instructions.
## ##############################################################################
echo -- Entering SilentInstall.sh --
# The files listed above should all be copied to a scripts directory
# For example /home/optim/scripts
# Get the path to the current batch file
OPTIM_SCRIPTS=${OPTIM_SCRIPTS:-"$( cd "$( dirname "${BASH_SOURCE[0]}" )" >/dev/null 2>&1 && pwd )"}
export OPTIM_SCRIPTS

echo Using OPTIM_SCRIPTS directory: ${OPTIM_SCRIPTS}

# If _HOME was set, use it, otherwise, use ${HOME}
_HOME=${_HOME:-${HOME}}
export _HOME

# The current major version being installed (e.g., 11.3.0.0 etc.)
MAJOR_VERSION=${MAJOR_VERSION:-11.7.0.0}
# The major version being uninstalled (e.g., 11.3.0.0, 11.7.0.0)
MAJOR_UNINSTALL_VERSION=${MAJOR_UNINSTALL_VERSION:-11.3.0.0}
# The current version without decimal points (e.g., 11700 etc.)
CURRENT_VERSION=${CURRENT_VERSION:-11700}
export MAJOR_VERSION MAJOR_UNINSTALL_VERSION CURRENT_VERSION

# 1=uninstall/install a component
UNINSTALL_RUNTIME=${UNINSTALL_RUNTIME:-1}
INSTALL_RUNTIME=${INSTALL_RUNTIME:-1}
UNINSTALL_SHARED=${UNINSTALL_SHARED:-1}
INSTALL_SHARED=${INSTALL_SHARED:-1}
export UNINSTALL_RUNTIME INSTALL_RUNTIME UNINSTALL_SHARED INSTALL_SHARED

# Internal use Only
UNINSTALL_JAVA=${UNINSTALL_JAVA:-0}
INSTALL_JAVA=${INSTALL_JAVA:-0}
UNINSTALL_TEST=${UNINSTALL_TEST:-0}
INSTALL_TEST=${INSTALL_TEST:-0}
export UNINSTALL_JAVA INSTALL_JAVA UNINSTALL_TEST INSTALL_TEST
# Specify false. A value of true is for internal use only
USE_OPTIM_JAVA=${USE_OPTIM_JAVA:-"false"}
_INTERNAL=${_INTERNAL:-0}
export USE_OPTIM_JAVA _INTERNAL

# The base installation directory (ending in Optim}
OPTIM_ROOT=${OPTIM_ROOT:-"${HOME}/IBM/InfoSphere/Optim"}
export OPTIM_ROOT

# Set the target OS. For
# AIX specify aix
# Linux/SuSE specify linux 
# Set the target windowing system. For
# AIX (11.3.0.8 only specify motif)
# AIX/Linux/SuSE specify gtk 
# Set application architecture. For
# AIX specify ppc
# Linux/SuSE specify x86 
case `uname -s` in
AIX)
   TARGET_OS=aix
   TARGET_WS=${TARGET_WS:-gtk}
   TARGET_ARCH=${TARGET_ARCH:-ppc}
   # The value for JRE_HOME (don't include bin)
   JRE_HOME=${JRE_HOME:-/usr/java8/jre}
   # The fully qualified path to the JVM
   JVM_PATH=${JVM_PATH:-${JRE_HOME}/lib/ppc/j9vm/libjvm.so}
   # The location of the Java library RELATIVE to the install directory
   # of Runtime Services (Deprecated)
   JVM_LOCATION=${JVM_LOCATION:-../../../../../../../${JVM_PATH}}
   # Only necessary for AIX
   LIBPATH=/opt/freeware/lib:/opt/freeware/lib64:$LIBPATH
   export LIBPATH
   ;;
Linux)
   TARGET_OS=linux
   TARGET_WS=${TARGET_WS:-gtk}
   TARGET_ARCH=${TARGET_ARCH:-x86}
   # The value for JRE_HOME (don't include bin)
   JRE_HOME=${JRE_HOME:-/opt/java_i586/jre1.8.0_271}
   # The fully qualified path to the JVM
   JVM_PATH=${JVM_PATH:-${JRE_HOME}/lib/i386/client/libjvm.so}
   # The location of the Java library RELATIVE to the install directory
   # of Runtime Services (Deprecated)
   JVM_LOCATION=${JVM_LOCATION:-../../../../../../../${JVM_PATH}}
   ;;
*)
   echo Unsupported Operating System
   _RC=1
   ;;
esac
export TARGET_OS TARGET_WS TARGET_ARCH JRE_HOME JVM_PATH JVM_LOCATION

# The shared installation directory used by all Installation Manager
# eclipse based products. This is NOT the same as the Optim Shared directory.
SDP_SHARED=${SDP_SHARED:-"${HOME}/IBM/Shared"}
export SDP_SHARED

# The directory that contains the expanded launchpad repository
# (it must contain the diskTag.inf)
#OPTIM_LAUNCHPAD=${OPTIM_LAUNCHPAD:-"${HOME}/Optim/repo/disk1"}
#export OPTIM_LAUNCHPAD

# The directory that contains the expanded install repository 
# (it must contain the repository.config)
OPTIM_FIXPACK_RUNTIME=${OPTIM_FIXPACK_RUNTIME:-"${_HOME}/Optim/${CURRENT_VERSION}/runtime${CURRENT_VERSION}_update"}
OPTIM_FIXPACK_WEB=${OPTIM_FIXPACK_WEB:-"${_HOME}/Optim/${CURRENT_VERSION}/web${CURRENT_VERSION}_update"}
# 11.3.0.8 Only
OPTIM_FIXPACK_WASCE=${OPTIM_FIXPACK_WASCE:-"${_HOME}/Optim/${CURRENT_VERSION}/wasce${CURRENT_VERSION}_update"}
export OPTIM_FIXPACK_RUNTIME OPTIM_FIXPACK_WASCE OPTIM_FIXPACK_WEB

# Internal Use Only
OPTIM_FIXPACK_JAVA=${OPTIM_FIXPACK_JAVA:-"${_HOME}/Optim/${CURRENT_VERSION}/java${CURRENT_VERSION}"}
OPTIM_FIXPACK_TEST=${OPTIM_FIXPACK_TEST:-"${_HOME}/Optim/${CURRENT_VERSION}/test${CURRENT_VERSION}"}
export OPTIM_FIXPACK_JAVA OPTIM_FIXPACK_TEST

# Information to shutdown Web Application Server
WEB_USER=${WEB_USER:-"system"}
WEB_PASSWORD=${WEB_PASSWORD:-"manager"}
JAVA_HOME=${JAVA_HOME:-"${OPTIM_ROOT}/shared/jdk"}
export WEB_USER WEB_PASSWORD JAVA_HOME 

# (Windows Only) Set to true to create desktop shortcuts
CREATE_DESKTOP_SHORTCUTS=false
# (Windows Only) Set to true to create Optim file associations (requires write access to the Windows Registry)
CREATE_OPTIM_FILE_ASSOCIATIONS=false
# (Windows Only) Set to true to populate the OptimConfigClient.pst file with Optim entries from the Windows Registry 
# WARNING: This action will wipe out any existing entries to the existing OptimConfigClient.pst 
# (requires read access to the Windows Registry)
# You can also select the Optim Registry Population start menu option to run this step later 
POPULATE_OPTIM_REGISTRY_INI=false
export CREATE_DESKTOP_SHORTCUTS CREATE_OPTIM_FILE_ASSOCIATIONS POPULATE_OPTIM_REGISTRY_INI

# The location of the OptimConfigServer.pst file installed by Runtime Services
OPTIM_CONFIG_SERVER_LOCATION=${OPTIM_CONFIG_SERVER_LOCATION:-"${OPTIM_ROOT}/rt/OptimConfigServer.pst"}
export OPTIM_CONFIG_SERVER_LOCATION

# Set true if you have one or more Optim Permanent License files
OPTIM_PERMANENT_LICENSE=${OPTIM_PERMANENT_LICENSE:-false}
# If OPTIM_PERMANENT_LICENSE is true, set to true if you have an Optim Data Grown Permanent license
OPTIM_PERMANENT_DG_LICENSE=${OPTIM_PERMANENT_DG_LICENSE:-false}
# If OPTIM_PERMANENT_DG_LICENSE is true, set to the directory (not file name) of the Optim Data Grown Permanent license file
OPTIM_PERMANENT_DG_LICENSE_DIRECTORY=${OPTIM_PERMANENT_DG_LICENSE_DIRECTORY:-' '}
# If OPTIM_PERMANENT_LICENSE is true, set to true if you have an Optim Test Data Management Permanent license
OPTIM_PERMANENT_TDM_LICENSE=${OPTIM_PERMANENT_TDM_LICENSE:-false}
# If OPTIM_PERMANENT_TDM_LICENSE is true, set to the directory (not file name) of the Optim Test Data Management Permanent license file
OPTIM_PERMANENT_TDM_LICENSE_DIRECTORY=${OPTIM_PERMANENT_TDM_LICENSE_DIRECTORY:-' '}
# If OPTIM_PERMANENT_LICENSE is true, set to true if you have an Optim Data Privacy Permanent license
OPTIM_PERMANENT_DP_LICENSE=${OPTIM_PERMANENT_DP_LICENSE:-false}
# If OPTIM_PERMANENT_DP_LICENSE is true, set to the directory (not file name) of the Optim Data Privacy Permanent license file
OPTIM_PERMANENT_DP_LICENSE_DIRECTORY=${OPTIM_PERMANENT_DP_LICENSE_DIRECTORY:-' '}
export OPTIM_PERMANENT_LICENSE
export OPTIM_PERMANENT_DG_LICENSE OPTIM_PERMANENT_DG_LICENSE_DIRECTORY
export OPTIM_PERMANENT_TDM_LICENSE OPTIM_PERMANENT_TDM_LICENSE_DIRECTORY
export OPTIM_PERMANENT_DP_LICENSE OPTIM_PERMANENT_DP_LICENSE_DIRECTORY

# Set to true to delete the OptimConfigClient.pst file at unintall times. 
# WARNING: Only set to true if do not plan on installing another instance of 
#	       Optim on this computer
DELETE_OPTIM_CONFIG_FILES=${DELETE_OPTIM_CONFIG_FILES:-false}
export DELETE_OPTIM_CONFIG_FILES
    
# (Windows Only) Set to true to delete the Optim entries in the Windows registry. 
# WARNING: Only set to true if do not plan on installing another instance of 
#	Optim on this computer
DELETE_OPTIM_WINDOWS_REGISTRY_ENTRIES=false
export DELETE_OPTIM_WINDOWS_REGISTRY_ENTRIES

# The IBM Installation Manager eclipse directory
IM_ROOT=${IM_ROOT:-"${HOME}/IBM/InstallationManager/eclipse"}
export IM_ROOT

# Set to admin or nonAdmin mode, depending on how Installation Manager is installed 
IM_INSTALL_MODE=${IM_INSTALL_MODE:=nonAdmin}
export IM_INSTALL_MODE

# Set TMP here to change the temporary directory used during installation.
TMP=${TMP:-/tmp}
export TMP

# Set this to true to print debug information for the IA installer (11.3.0.8 or earlier)
LAX_DEBUG=${LAX_DEBUG:-false}
export LAX_DEBUG
# ::::::::::::::::::::::::::::::::::::::::::::::::::
# No changes should be needed below this line
# ::::::::::::::::::::::::::::::::::::::::::::::::::
if [ "${MAJOR_UNINSTALL_VERSION}" != "11.3.0.0" ] ; then
   if [ "${MAJOR_UNINSTALL_VERSION}" != "11.7.0.0" ] ; then
      if [ "${UNINSTALL_RUNTIME}" == "1" ] ; then
         echo MAJOR_UNINSTALL_VERSION must be 11.3.0.0 or 11.7.0.0.
         _RC=99
         exit ${_RC}
      elif [ "${UNINSTALL_SHARED}" == "1" ] ; then
         echo MAJOR_UNINSTALL_VERSION must be 11.3.0.0 or 11.7.0.0, found: $MAJOR_UNINSTALL_VERSION.
         _RC=99
         exit ${_RC}
      fi
   fi
fi

if [ "${INSTALL_RUNTIME}" == "1" ] ; then
   if [ ! -f "${JVM_PATH}" ] ; then
      echo The JVM ${JVM_PATH} not found.
      echo Optim requires a JVM at install and runtime.
      _RC=9
      exit ${_RC}
   fi
fi
if [ "${INSTALL_TEST}" == "1" ] ; then
   if [ ! -f "${JVM_PATH}" ] ; then
      echo The JVM ${JVM_PATH} not found.
      echo Optim requires a JVM at install and runtime.
      _RC=9
      exit ${_RC}
   fi
fi

# 11.3.0.8 Only
WEB_STOP=shutdown.sh
WEB_BIN=${OPTIM_ROOT}/shared/WebSphere/AppServerCommunityEdition/bin
# 11.7 and higher
_WEB_BIN=${OPTIM_ROOT}/shared/web/app
_WEB_PGM=internal
_WEB_PARM=liberty
_WEB_STATUS=status
_WEB_START=start
_WEB_STOP=stop

TEST_RUNTIME=0
TEST_SHARED=0
if [ "${INSTALL_RUNTIME}" == "1" ] ; then
   TEST_RUNTIME=1
fi
if [ "${UNINSTALL_RUNTIME}" == "1" ] ; then
   TEST_RUNTIME=1
fi
if [ "${INSTALL_SHARED}" == "1" ] ; then
   TEST_SHARED=1
fi
if [ "${UNINSTALL_SHARED}" == "1" ] ; then
   TEST_SHARED=1
fi

# Internal use only
TEST_JAVA=0
if [ "${INSTALL_JAVA}" == "1" ] ; then
   TEST_JAVA=1
fi
if [ "${UNINSTALL_JAVA}" == "1" ] ; then
   TEST_JAVA=1
fi
if [ "${INSTALL_TEST}" == "1" ] ; then
   TEST_TEST=1
fi
if [ "${UNINSTALL_TEST}" == "1" ] ; then
   TEST_TEST=1
fi

# If a Launch pad is specified, it must exist
if [ ! -z "${OPTIM_LAUNCHPAD}" ] ; then 
   if [ ! -f ${OPTIM_LAUNCHPAD}/diskTag.inf ] ; then
      _RC=9
      echo  The Optim Launchpad repository ${OPTIM_LAUNCHPAD} was not found or does not contain the diskTag.inf file. 
      echo -- Exiting SilentInstall --
      exit ${_RC}
   fi
fi

if [ "${INSTALL_RUNTIME}" == "1" ] ; then
   # Ensure the installer repository can be found
   if [ ! -f ${OPTIM_FIXPACK_RUNTIME}/repository.config ] ; then
      _RC=10
      echo The Optim installer repository ${OPTIM_FIXPACK_RUNTIME} was not found or does not contain the repository.config file.
      echo -- Exiting SilentInstall --
      exit ${_RC}
   fi
fi

# The following is needed for an install and uninstall
if [ "${TEST_RUNTIME}" == "1" ] ; then
   if [ ! -f "${OPTIM_ROOT}/rt/bin/rtbuild.h" ] ; then
      echo Runtime Services is not installed. Skipping the uninstall step.
      UNINSTALL_RUNTIME=0
      export UNINSTALL_SHARED
   fi

   # Only Uninstall is supported with this version of SilentInstall.sh
   OPTIM_SERVER_INSTALLER=${OPTIM_SCRIPTS}/OptimSilentInstall.sh
   export OPTIM_SERVER_INSTALLER

   # The OptimSilentUninstall.sh script file (for 11.3.0.8)
   OPTIM_SERVER_UNINSTALLER=${OPTIM_SCRIPTS}/OptimSilentUninstall.sh
   export OPTIM_SERVER_UNINSTALLER

   # The following only applies to 11.3.0.x
   if [ "${MAJOR_UNINSTALL_VERSION}" == "11.3.0.0" ] ; then 
      # Ensure the the OptimSilentUninstall.sh script file exists
      if [ ! -f "${OPTIM_SERVER_UNINSTALLER}" ] ; then
         _RC=12
         echo The Optim Server Uninstaller script file ${OPTIM_SERVER_UNINSTALLER} was not found.
         echo -- Exiting SilentInstall --
         exit ${_RC}
      fi
   fi
fi

if [ "${INSTALL_SHARED}" == "1" ] ; then
   # Ensure the installer repository can be found
   if [ ! -f ${OPTIM_FIXPACK_WEB}/repository.config ] ; then
      _RC=10
      echo The Optim repository ${OPTIM_FIXPACK_WEB} was not found or does not contain the repository.config file.
      echo -- Exiting SilentInstall --
      exit ${_RC}
   fi
   if [ ${_SOA_VER} == "11.3.0.8" ] ; then
      # Ensure the installer repository can be found
      if [ ! -f ${OPTIM_FIXPACK_WASCE}/repository.config ] ; then
         _RC=10
         echo The Optim repository ${OPTIM_FIXPACK_WASCE} was not found or does not contain the repository.config file.
         echo -- Exiting SilentInstall --
         exit ${_RC}
      fi
   fi
fi

# The following is needed for an install and uninstall
if [ "${TEST_SHARED}" == "1" ] ; then
   if [ ! -f ${OPTIM_ROOT}/shared/web/app/optim.unified.web.app.war ] ; then
      echo Web Applications is not installed at ${OPTIM_ROOT}/shared/web. Skipping the uninstall step.
      UNINSTALL_SHARED=0
      export UNINSTALL_SHARED
   elif [ "${MAJOR_UNINSTALL_VERSION}." == "11.3.0.0." ] ; then
      echo Testing if ${WEB_BIN}/${WEB_STOP} exists...
      if [ -f "${WEB_BIN}/${WEB_STOP}" ] ; then
         echo Shutting down Web Applications Server...
         sh ${WEB_BIN}/${WEB_STOP} --user ${WEB_USER} --password ${WEB_PASSWORD}
         _RC=$?
         if [ "${_RC}" != "0" ] ; then
            echo ${WEB_BIN}/${WEB_STOP} returned ${_RC}
         else
            echo The Web Application Server is not running.
         fi
      else
         echo WARNING: The WAS-CE script ${WEB_BIN}/${WEB_STOP} not found.
      fi
   elif [ "${MAJOR_UNINSTALL_VERSION}" == "11.7.0.0" ] ; then
      echo Testing if ${_WEB_BIN}/${_WEB_PGM} exists...
      if [ -f ${_WEB_BIN}/${_WEB_PGM} ] ; then
         cd ${_WEB_BIN}
         sh ./${_WEB_PGM} ${_WEB_PARM} ${_WEB_STOP}
         _RC=$?
         if [ ${_RC} -ne 0 ] ; then
            echo Failed to stop the Web Application Server...
            exit ${_RC}
         fi
      else
         echo WARNING: The Liberty script ${_WEB_BIN}/${_WEB_PGM} not found.
      fi
   fi
fi

if [ "${INSTALL_TEST}" == "1" ] ; then
   # Ensure the installer repository can be found
   if [ ! -f ${OPTIM_FIXPACK_TEST}/repository.config ] ; then
      _RC=10
      echo The Optim installer repository ${OPTIM_FIXPACK_TEST} was not found or does not contain the repository.config file.
      echo -- Exiting SilentInstall --
      exit ${_RC}
   fi
fi

# The tools subdirectory off the IBM Installation Manager installation directory
# If IM_ROOT is correct, you should not change this value.
IM_TOOLS_DIR=${IM_ROOT}/tools
export IM_TOOLS_DIR

# The environment variable used by the Optim Server feature installer
IATEMPDIR=${TMP}
export IATEMPDIR

# Ensure the system temporary directory exist
if [ ! -d ${IATEMPDIR} ] ; then
   echo The temporary directory ${IATEMPDIR} does not exist!
   _RC=8
   exit ${_RC}
fi

# In 11.3.0.8, the installation log location
OPTIM_INSTALL_LOGS=${IATEMPDIR}/OptimLogs
export OPTIM_INSTALL_LOGS

# Ensure the OptimLogs directory exists
if [ ! -d ${OPTIM_INSTALL_LOGS} ]; then mkdir ${OPTIM_INSTALL_LOGS} ; fi 

# Clear out previous log files
if [ -f ${OPTIM_ROOT}/Uninstall_Optim/Logs/IBM_InfoSphere_Optim_InstallLog.log ]; then rm -f ${OPTIM_ROOT}/Uninstall_Optim/Logs/IBM_InfoSphere_Optim_InstallLog.log; fi
# 11.3.0.7
if [ -f /tmp/IADebugInfoOptim ]; then rm -f /tmp/IADebugInfoOptim ; fi
# 11.3.0.8
if [ -f ${OPTIM_INSTALL_LOGS}/IAOptimInstall.log ]; then rm -f ${OPTIM_INSTALL_LOGS}/IAOptimInstall.log ;fi
if [ -f ${OPTIM_INSTALL_LOGS}/IADebugInfoOptim ]; then rm -f ${OPTIM_INSTALL_LOGS}/IADebugInfoOptim ;fi
if [ -f ${OPTIM_INSTALL_LOGS}/installRuntime_log.xml ]; then rm -f ${OPTIM_INSTALL_LOGS}/installRuntime_log.xml ;fi
if [ -f ${OPTIM_INSTALL_LOGS}/uninstallRuntime_log.xml ]; then rm -f ${OPTIM_INSTALL_LOGS}/uninstallRuntime_log.xml ;fi
if [ -f ${OPTIM_INSTALL_LOGS}/installShared_log.xml ]; then rm -f ${OPTIM_INSTALL_LOGS}/installShared_log.xml ;fi
if [ -f ${OPTIM_INSTALL_LOGS}/uninstallShared_log.xml ]; then rm -f ${OPTIM_INSTALL_LOGS}/uninstallShared_log.xml ;fi

if [ ! -f ${IM_TOOLS_DIR}/imcl ] ; then
   echo The Installation Manager command line tool ${IM_TOOLS_DIR}/imcl was not found.
   echo -- Exiting SilentInstall --
   exit 10
fi

# Changed to the Installation Manager tools directory 
cd ${IM_TOOLS_DIR}

# ##############################################################################
# Uninstall Optim Runtime Services
if [ "${UNINSTALL_RUNTIME}" == "1" ] ; then
   echo  Uninstalling Optim Runtime Services...
   ./imcl -accessRights ${IM_INSTALL_MODE} -input ${OPTIM_SCRIPTS}/uninstallRuntime.xml -log ${OPTIM_INSTALL_LOGS}/uninstallRuntime_log.xml
   _RC=$?
   echo imcl [uninstall Optim Runtime Services] exited with the RC ${_RC}
fi
# ##############################################################################
# Install Optim Runtime Services
if [ "${INSTALL_RUNTIME}" == "1" ] ; then
   echo  Installing Optim Runtime Services...
   ./imcl -accessRights ${IM_INSTALL_MODE} -input ${OPTIM_SCRIPTS}/installRuntime.xml -log ${OPTIM_INSTALL_LOGS}/installRuntime_log.xml -acceptLicense
   _RC=$?
   echo imcl [install Optim Runtime Services] exited with the RC ${_RC}
   if [ "${_RC}" != "0" ] ; then
      exit ${_RC}
   fi
   if [ ! -f "${OPTIM_ROOT}/rt/bin/rtbuild.h" ] ; then
      _RC=99
      echo ERROR *** Optim server feature failed to install ***!
      exit ${_RC}
   fi
fi

# ##############################################################################
# Uninstall Optim Shared Components (Optim Web Applications and WAS-CE for 11.3.0.8)
if [ "${UNINSTALL_SHARED}" == "1" ] ; then
   echo  Uninstalling Optim Shared Components...
   ./imcl -accessRights ${IM_INSTALL_MODE} -input ${OPTIM_SCRIPTS}/${_UNINSTALL_SHARED_XML} -log ${OPTIM_INSTALL_LOGS}/uninstallShared_log.xml
   _RC=$?
   echo imcl [uninstall Optim Shared Components] exited with the RC ${_RC}
fi
## ##############################################################################
# Install Optim Shared Components (Optim Web Applications and WAS-CE for 11.3.0.8)
if [ "${INSTALL_SHARED}" == "1" ] ; then
   echo Installing Optim Shared Components...
   ./imcl -input ${OPTIM_SCRIPTS}/installShared.xml -log ${OPTIM_INSTALL_LOGS}/installShared_log.xml  -acceptLicense
   _RC=$?
   echo imcl [Install Optim Shared Components] exited with the RC ${_RC}
   if [ "${_RC}" != "0" ] ; then
      exit ${_RC}
   fi
fi

# ##############################################################################
# Uninstall Optim Java (Internal Use Only)
if [ "${UNINSTALL_JAVA}" == "1" ] ; then
   echo  Uninstalling Optim Java Component...
   ./imcl -accessRights ${IM_INSTALL_MODE} -input ${OPTIM_SCRIPTS}/uninstallSharedJava.xml -log ${OPTIM_INSTALL_LOGS}/uninstallSharedJava_log.xml
   _RC=$?
   echo imcl [uninstall Optim Java] exited with the RC ${_RC}
fi
## ##############################################################################
# Install Optim Java (Internal Use Only)
if [ "${INSTALL_JAVA}" == "1" ] ; then
   echo Installing Optim Java...
   ./imcl -input ${OPTIM_SCRIPTS}/installSharedJava.xml -log ${OPTIM_INSTALL_LOGS}/installSharedJava_log.xml  -acceptLicense
   _RC=$?
   echo imcl [Install Optim Java] exited with the RC ${_RC}
fi
# ##############################################################################
# Uninstall Optim Test (Internal Use Only)
if [ "${UNINSTALL_TEST}" == "1" ] ; then
   echo  Uninstalling Optim Test Component...
   ./imcl -accessRights ${IM_INSTALL_MODE} -input ${OPTIM_SCRIPTS}/uninstallTest.xml -log ${OPTIM_INSTALL_LOGS}/uninstallTest_log.xml
   _RC=$?
   echo imcl [uninstall Optim Test] exited with the RC ${_RC}
fi
## ##############################################################################
# Install Optim Test (Internal Use Only)
if [ "${INSTALL_TEST}" == "1" ] ; then
   echo Installing Optim Test...
   ./imcl -input ${OPTIM_SCRIPTS}/installTest.xml -log ${OPTIM_INSTALL_LOGS}/installTest_log.xml  -acceptLicense
   _RC=$?
   echo imcl [Install Optim Test] exited with the RC ${_RC}
fi

# Display found log files
# 11.3.0.7
if [ -f ${OPTIM_ROOT}/Uninstall_Optim/Logs/IBM_InfoSphere_Optim_InstallLog.log ]; then echo Found log file:  ${OPTIM_ROOT}/Uninstall_Optim/Logs/IBM_InfoSphere_Optim_InstallLog.log; fi
if [ -f /tmp/IADebugInfoOptim ]; then echo Found log file:  /tmp/IADebugInfoOptim ; fi
# 11.3.0.8
if [ -f ${OPTIM_INSTALL_LOGS}/IBM_InfoSphere_Optim_InstallLog.log ]; then echo Found log file: ${OPTIM_INSTALL_LOGS}/IBM_InfoSphere_Optim_InstallLog.log; fi
if [ -f ${OPTIM_INSTALL_LOGS}/IAOptimInstall.log ]; then echo Found log file: ${OPTIM_INSTALL_LOGS}/IAOptimInstall.log ;fi
if [ -f ${OPTIM_INSTALL_LOGS}/IADebugInfoOptim ]; then echo Found log file:${OPTIM_INSTALL_LOGS}/IADebugInfoOptim ;fi
if [ -f ${OPTIM_INSTALL_LOGS}/installRuntime_log.xml ]; then echo Found log file: ${OPTIM_INSTALL_LOGS}/installRuntime_log.xml ;fi
if [ -f ${OPTIM_INSTALL_LOGS}/uninstallRuntime_log.xml ]; then echo Found log file: ${OPTIM_INSTALL_LOGS}/uninstallRuntime_log.xml ;fi
if [ -f ${OPTIM_INSTALL_LOGS}/installShared_log.xml ]; then echo Found log file: ${OPTIM_INSTALL_LOGS}/installShared_log.xml ;fi
if [ -f ${OPTIM_INSTALL_LOGS}/uninstallShared_log.xml ]; then echo Found log file: ${OPTIM_INSTALL_LOGS}/uninstallShared_log.xml ;fi
if [ -f ${OPTIM_INSTALL_LOGS}/installTest_log.xml ]; then echo Found log file: ${OPTIM_INSTALL_LOGS}/installTest_log.xml ;fi
if [ -f ${OPTIM_INSTALL_LOGS}/uninstallTest_log.xml ]; then echo Found log file: ${OPTIM_INSTALL_LOGS}/uninstallTest_log.xml ;fi

echo Exiting SilentInstall with a return code of ${_RC}.
echo -- Exiting SilentInstall.sh -- 
exit ${_RC}
# --- End of script ---
