#!/bin/bash
## #############################################################################
# optimsetenv.sh
#
#     Licensed Materials - Property of IBM
#    "Restricted Materials of IBM"
#
#    5724-U38, 5724-U39, 5724-U48
#
#     Copyright IBM Corp. 2021 All Rights Reserved
#
#     Copyright 2021 UNICOM Systems, Inc. - All Rights Reserved
#
#    US Government Users Restricted Rights - Use, duplication or
#    disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# Unix shell script, sourced by optimutil.sh, used to set up the environment
# for installing Optim in silent or console modes, and updating Optim's
# configuration files that specify the JRE and JVM locations in Linux or AIX.
#
# Refer to the companion ReadMe.txt file for instructions.
## ##############################################################################
echo Setting the default environment for $HOSTNAME

# Set the Optim user's home directory
_HOME=${HOME}
export _HOME

# Specify the base installation directory (ending in Optim}
OPTIM_ROOT=${_HOME}/IBM/InfoSphere/Optim
export OPTIM_ROOT

# Specify the directory that contains the optimutil and user modified optimsetenv scripts
# For ease of use, it is recommended that you also copy your Optim License files to this directory
_ROOT_DIR=${_HOME}/Jenkins
# Uncomment only one of the following two lines if you leave the supporting scripts in their original install location
# _SCRIPTS_DIR=${OPTIM_ROOT}/services/scripts
# _SCRIPTS_DIR=${OPTIM_ROOT}/shared/scripts
# Comment the following line if you did not copy all of the script files and you are using one of the above
_SCRIPTS_DIR=${_ROOT_DIR}
export _ROOT_DIR _SCRIPTS_DIR

# Set the target OS. For
# AIX specify aix
# Linux/SuSE specify linux 
# Set the target windowing system. For
# AIX/Linux/SuSE specify gtk
# Set application architecture. For
# AIX specify ppc
# Linux/SuSE specify x86 
case `uname -s` in
AIX)
   TARGET_OS=aix
   # For 11.7 this must be gtk, for 11.3 use motif
   TARGET_WS=gtk
   TARGET_ARCH=ppc
   # Supported in a post 11.7 release tbd
   #TARGET_ARCH=ppc64
   # Specify the location of a gnu Tar
   # You can download the GNU tar from
   # https://www.ibm.com/support/pages/aix-toolbox-linux-applications-downloads-alpha
   _ZIP=/opt/freeware/bin/tar
   # SED (Stream EDitor) is typically part of the base OS installation
   _SED=/usr/bin/sed
   _BROWSER=/usr/bin/lynx
   # Specify the value for JRE_HOME (don't include bin)
   JRE_HOME=/usr/java8/jre
   # Specify the fully qualified path to the JVM
   JVM_PATH=${JRE_HOME}/lib/ppc/j9vm/libjvm.so
   # Specify the location of the Java library RELATIVE to the install directory
   # of Runtime Services (Deprecated)
   JVM_LOCATION=../../../../../../../${JVM_PATH}
   # When calling optimutil.sh to update the JRE, specify the OLD JRE_HOME value here.
   JRE_HOME_OLD=
   # When calling optimutil.sh to update the JVM, specify the OLD JRE_PATH value here.
   JVM_PATH_OLD=
   # Only necessary for AIX
   LIBPATH=/opt/freeware/lib:/opt/freeware/lib64:$LIBPATH
   export LIBPATH
   ;;
Linux)
   TARGET_OS=linux
   TARGET_WS=gtk
   TARGET_ARCH=x86
   # Supported in a post 11.7 release tbd
   #TARGET_ARCH=x86_64
   # Specify the location of a gnu Tar
   # You can download the GNU tar from www.gnu.org
   if [ -f /etc/redhat-release ] ; then
      _ZIP=/usr/bin/tar
   elif [ -f /etc/SuSE-release ] ; then
      _ZIP=/bin/tar
   else
      echo Unsupported Linux Variant
      _RC=1
   fi
   # SED (Stream EDitor) is typically part of the base OS installation
   _SED=/usr/bin/sed
   _BROWSER=/usr/bin/firefox
   # Specify the value for JRE_HOME (don't include bin)
   JRE_HOME=/opt/java_i586/java-se-8u41-ri
   # Specify the fully qualified path to the JVM
   JVM_PATH=/opt/java_i586/java-se-8u41-ri/lib/i386/client/libjvm.so
   # When calling optimutil.sh to update the JRE, specify the OLD JRE_HOME value here.
   JRE_HOME_OLD=/opt/java_i586/jre1.8.0_271
   # When calling optimutil.sh to update the JVM, specify the OLD JRE_PATH value here.
   JVM_PATH_OLD=/opt/java_i586/jre1.8.0_271/lib/i386/client/libjvm.so
   # Specify the location of the Java library RELATIVE to the install directory
   # of Runtime Services (Deprecated)
   JVM_LOCATION=../../../../../../../${JVM_PATH}
   ;;
*)
   echo Unsupported Operating System
   _RC=1
   ;;
esac
export TARGET_OS TARGET_WS TARGET_ARCH _ZIP _SED _BROWSER JRE_HOME JVM_PATH JRE_HOME_OLD JVM_PATH_OLD  JVM_LOCATION

# The IBM Installation Manager root
IM_ROOT=${_HOME}/IBM/InstallationManager/eclipse
export IM_ROOT

# The location of the Installation Manager command line tool
_IM_TOOL=${_IM_ROOT}/tools/imcl
export _IM_TOOL

# You can download wget from www.gnu.org
_WGET=/usr/bin/wget
export _WGET

# Set to true to print debug information from the IA installer when uninstalling 11.3.0.x
LAX_DEBUG=false
export LAX_DEBUG 

# Specify the location of the shared directory
SDP_SHARED=${_HOME}/IBM/Shared
export SDP_SHARED

# These can be overwritten by optimutil command line parameters
# Use 1 to install as an administrator or 0 to install as a non-administrator user
# depending on how Installation Manager is installed 
_ADMIN=0
# The following are only valid with --install
_KEEP=1
_USE_EXISTING=1
_UPDATE=0
_DOWNLOAD=0
_SOA_QUALIFIER=local
# Set to the current (release or fixpack) version without "." (e.g., 11700, 11701, etc.)
_SOA_VER=11700
export _ADMIN _KEEP _USE_EXISTING _UPDATE _DOWNLOAD _SOA_QUALIFIER _SOA_VER

# Ensure ${_RC} contains the last return code
# Usually, these should not be changed.
_RC=0
_URL=
_DEBUG=0
_MERGE=0
_TMP=/tmp
export _RC _URL _DEBUG _MERGE _TMP

# These are managed by the optimutil script 
#UNINSTALL_RUNTIME=1
#INSTALL_RUNTIME=1
#UNINSTALL_SHARED=1
#INSTALL_SHARED=1
#export UNINSTALL_RUNTIME INSTALL_RUNTIME UNINSTALL_SHARED INSTALL_SHARED

# Internal Use Only
UNINSTALL_JAVA=0
INSTALL_JAVA=0
UNINSTALL_TEST=0
INSTALL_TEST=0
# Must be false. A value of true is for internal use only
USE_OPTIM_JAVA=false
# Must be 0. A value of 1 is for internal use only
_INTERNAL=0
export UNINSTALL_JAVA INSTALL_JAVA UNINSTALL_TEST INSTALL_TEST USE_OPTIM_JAVA _INTERNAL


# Specify information to shutdown WAS-CE Application Server (11.3.0.8 only)
WEB_USER=system
WEB_PASSWORD=manager
JAVA_HOME=${JRE_HOME}
export WEB_USER WEB_PASSWORD JAVA_HOME 

# (Windows Only) Set to true to create desktop shortcuts
CREATE_DESKTOP_SHORTCUTS=false
# (Windows Only) Set to true to create Optim file associations (requires write access to the Windows Registry)
CREATE_OPTIM_FILE_ASSOCIATIONS=false
# (Windows Only) Set to true to populate the OptimConfigClient.pst file with Optim entries from the Windows Registry 
# WARNING: This action will wipe out any existing entries to the existing OptimConfigClient.pst 
# (requires read access to the Windows Registry)
# You can also select the Optim Config Population start menu option to run this step later 
POPULATE_OPTIM_CONFIG=false
export CREATE_DESKTOP_SHORTCUTS CREATE_OPTIM_FILE_ASSOCIATIONS POPULATE_OPTIM_CONFIG

# Set to true to delete the OptimConfigClient/Server.pst file at unintall times. 
# WARNING: Only set to true if do not plan on installing another instance of 
#	       Optim on this computer
DELETE_OPTIM_CONFIG_FILES=false
export DELETE_OPTIM_CONFIG_FILES

# (Windows Only) Set to true to delete the Optim entries in the Windows registry. 
# WARNING: Only set to true if do not plan on installing another instance of 
#	Optim on this computer
DELETE_OPTIM_WINDOWS_REGISTRY_ENTRIES=false
export DELETE_OPTIM_WINDOWS_REGISTRY_ENTRIES

# Specify the location of the OptimConfigServer.pst file installed by Runtime Services
OPTIM_CONFIG_SERVER_LOCATION=${OPTIM_ROOT}/rt/OptimConfigServer.pst
export OPTIM_CONFIG_SERVER_LOCATION

# Set true if you have one or more Optim Permanent License files
OPTIM_PERMANENT_LICENSE=true
# If OPTIM_PERMANENT_LICENSE is true, set to true if you have an Optim Data Grown Permanent license
OPTIM_PERMANENT_DG_LICENSE=true
# If OPTIM_PERMANENT_DG_LICENSE is true, set to the directory (not file name) of the Optim Data Grown Permanent license file
OPTIM_PERMANENT_DG_LICENSE_DIRECTORY=${_ROOT_DIR}
# If OPTIM_PERMANENT_LICENSE is true, set to true if you have an Optim Test Data Management Permanent license
OPTIM_PERMANENT_TDM_LICENSE=true
# If OPTIM_PERMANENT_TDM_LICENSE is true, set to the directory (not file name) of the Optim Test Data Management Permanent license file
OPTIM_PERMANENT_TDM_LICENSE_DIRECTORY=${_ROOT_DIR}
# If OPTIM_PERMANENT_LICENSE is true, set to true if you have an Optim Data Privacy Permanent license
OPTIM_PERMANENT_DP_LICENSE=true
# If OPTIM_PERMANENT_DP_LICENSE is true, set to the directory (not file name) of the Optim Data Privacy Permanent license file
OPTIM_PERMANENT_DP_LICENSE_DIRECTORY=${_ROOT_DIR}
export OPTIM_PERMANENT_LICENSE
export OPTIM_PERMANENT_DG_LICENSE OPTIM_PERMANENT_DG_LICENSE_DIRECTORY
export OPTIM_PERMANENT_TDM_LICENSE OPTIM_PERMANENT_TDM_LICENSE_DIRECTORY
export OPTIM_PERMANENT_DP_LICENSE OPTIM_PERMANENT_DP_LICENSE_DIRECTORY

# Set to the current major version being installed (e.g., 11.3.0.0 etc.)
MAJOR_VERSION=11.7.0.0
# Set to the major version being uninstalled (e.g., 11.3.0.0, 11.7.0.0)
MAJOR_UNINSTALL_VERSION=11.3.0.0
# Set to the current (fixpack) version with out "." (e.g., 11308, 11309, 11700 etc.)
CURRENT_VERSION=${_SOA_VER}
export MAJOR_VERSION MAJOR_UNINSTALL_VERSION CURRENT_VERSION

# Specify the location of the base Launch pad repository
# Note: it must end with disk1
#OPTIM_LAUNCHPAD=${_SCRIPTS_DIR}/launchpad/11.3.0.4/repo/disk1
#export OPTIM_LAUNCHPAD 

# Set to the location of the expanded Runtime Services install repository
OPTIM_FIXPACK_RUNTIME=${_SCRIPTS_DIR}/runtime
# Set to the location of the expanded Web Applications install repository 
OPTIM_FIXPACK_WEB=${_SCRIPTS_DIR}/shared/web
export OPTIM_FIXPACK_RUNTIME OPTIM_FIXPACK_WEB

# Internal Use Only
OPTIM_FIXPACK_JAVA=${_SCRIPTS_DIR}/shared/java
OPTIM_FIXPACK_TEST=${_SCRIPTS_DIR}/test
export OPTIM_FIXPACK_JAVA OPTIM_FIXPACK_TEST

