#!/bin/bash
## #############################################################################
# optimutil.sh
#
#    Licensed Materials - Property of IBM
#    "Restricted Materials of IBM"
#
#    5724-U38, 5724-U39, 5724-U48
#
#     Copyright IBM Corp. 2021 All Rights Reserved
#
#     Copyright 2021 UNICOM Systems, Inc. - All Rights Reserved
#
#    US Government Users Restricted Rights - Use, duplication or
#    disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# Linux/Unix shell script that can be used to:
#    Install or uninstall an Optim Component in silent mode
#    Start Installation Manager in console mode
#    Update the JRE and JVM location for a currently installed Optim Component
#    Perform a silent install or update the JRE/JVM in an automated way
#
# Supported Optim Components:
# Optim Runtime Services, and Optim Web Applications
#
# Refer to the ReadMe.txt file for instructions on using this script file.
#
# Run this script with no parameters for command syntax.
## #############################################################################

# ##############################################################################
# exitCode    Display and exit an exit code
# ##############################################################################
exitCode() {
   if [ ! "${_RC}" == "0" ] ; then
      echo Use --help to display the syntax.
   fi
   echo Complete. RC=${_RC}
   exit ${_RC}
}

# ##############################################################################
# exitScript Exit with a message and return code
# ##############################################################################
exitScript() {
   if [ "${_PERFORM}" == "1" ] ; then
      if [ "${_RC}" == "0" ] ; then
         if [ "${_KEEP}." == "0." ] ; then
            if [ -f "${_SCRIPTS_DIR}/${_TAR_GZ}" ] ; then
               echo Removing ${_SCRIPTS_DIR}/${_TAR_GZ}
               rm -f ${_SCRIPTS_DIR}/${_TAR_GZ}
            fi
         fi
      fi
   fi
   exitCode
}

# ##############################################################################
# consoleInstall  Starts IM in console mode
# ##############################################################################
consoleInstall() {

   if [ -z ${_SOA_COMPONENT} ] ; then
      ${_IM_TOOL} -consoleMode -accessRights ${IM_INSTALL_MODE}
      _RC=$?
   else
      case "${_SOA_COMPONENT}" in
      runtime)
         _REPO_DIR=${OPTIM_FIXPACK_RUNTIME}
         _IM_PACKAGE='com.ibm.nex.proxy'
      ;;
      java)
         # Internal Use Only
         _REPO_DIR=${OPTIM_FIXPACK_JAVA}
         _IM_PACKAGE='com.ibm.nex.java'
         ;;
      test)
         # Internal Use Only
         _REPO_DIR=${OPTIM_FIXPACK_TEST}
         _IM_PACKAGE='com.ibm.nex.test'
         ;;
       web)
         _REPO_DIR=${OPTIM_FIXPACK_WEB}
         _IM_PACKAGE='com.ibm.nex.console'
         ;;
      *)
         echo --com[ponent] must be runtime or web.
         _RC=4
         exitCode
         ;;
      esac
      ${_IM_TOOL} -consoleMode -accessRights ${IM_INSTALL_MODE} -repositories ${_REPO_DIR} install ${_IM_PACKAGE}
      _RC=$?
   fi
   echo The Installation Manager console tool completed. 
   exitScript
}

# ##############################################################################
# displayCommand Display the current command
# ##############################################################################
displayCommand() {
   echo Running the following command:
   echo ${_THIS_SCRIPT} --${_ACTION}
   echo    --com ${_SOA_COMPONENT} --roo ${OPTIM_ROOT}
   if [ "${_ACTION}" == "install" ] ; then
      echo    --ver ${_SOA_VER} --unv ${MAJOR_UNINSTALL_VERSION} --qua ${_SOA_QUALIFIER}
      echo    --kee ${_KEEP} --del ${_DELETE} --upd ${_UPDATE} --use ${_USE_EXISTING} --dow ${_DOWNLOAD}
   elif [ "${_ACTION}" == "java" ] ; then
      echo    --jre ${JRE_HOME} --oje ${JRE_HOME_OLD}
      echo    --jvm ${JVM_PATH} --ojm ${JVM_PATH_OLD}
   fi
}

# ##############################################################################
# displayStatus Display the installed Optim offerings
# ##############################################################################
displayStatus() {
   if [ -z ${_IM_TOOL} ] ; then   
      echo ERROR: The Installation Manager tool was not defined in the variable _IM_TOOL.
      _RC=9
   elif [ -f ${_IM_TOOL} ] ; then   
      echo Installed packages:
      ${_IM_TOOL} -s listinstalledpackages -accessRights ${IM_INSTALL_MODE}
      _RC=$?
   else
      echo ERROR: Can not find the Installation Manager tool ${_IM_TOOL}.
      _RC=9
   fi
   if [ -f "${OPTIM_ROOT}/rt/bin/version.txt" ] ; then tail "${OPTIM_ROOT}/rt/bin/version.txt" ; fi
   exitCode
}

# ##############################################################################
# displaySyntax  Displays the command syntax and exits
# ##############################################################################
displaySyntax() {
   echo Syntax:
   echo  ${_THIS_SCRIPT} [option] command [--com COMPONENT [parameters...]
   echo  Where option is the following:
   echo     --adm [1=run as an administrator, 0=run as a user]
   echo     --roo [OPTIM_ROOT=Optim root directory]
   echo  Where command is one of the following:
   echo     --help Display this help, then exit 
   echo     --install Install an Optim Component
   echo     --console Start Installation Manager in console mode to install an Optim Component
   echo     --java Update the JRE_HOME and JVM used by Optim
   echo     --status Display the status of installed components, then exit
   echo  For --install and --java, you must specify an Optim component [Optional for --console]
   echo     --com [COMPONENT=runtime or web]
   echo     --jre [JRE_HOME=value for JRE_HOME] No embedded spaces permitted if passed as a parameter
   echo     --jvm [JVM_PATH=path to the libjvm.so] No embedded spaces permitted if passed as a parameter
   echo  Additional parameters for --java:
   echo     --oje [JRE_HOME_OLD=old value for JRE_HOME] No embedded spaces permitted if passed as a parameter
   echo     --ojm [JVM_PATH_OLD=old path to the libjvm.so]  No embedded spaces permitted if passed as a parameter
   echo  Additional parameters for --install in silent mode only:
   echo     --del [0=uninstall, then install, 1=uninstall only]
   echo     --kee [0=don\'t keep, 1=keep] downloaded artifact
   echo     --qua [QUALIFIER]=\'local\' or the fully qualified timestamp
   echo     --upd [0=uninstall/install or 1=update] 
   echo     --unv [UNinstallVersion=the 4 position major uninstall version with 3 decimal points \(i.e., 11.3.0.0\)]
   echo     --use [0=new repository, 1=existing repository]
   echo     --ver [VER=is the 4 position version with no decimal points \(i.e., 11700\)]
   echo  Advanced parameters for --install:
   echo     --dow [0=don\'t download, 1=download] the installer for a local network drive
   echo     --url [URL of local network drive]
   echo  Where:
   echo  "  QUALIFIER A fully qualified timestamp YYYYMMDD_HHSS for a tar.gz file;"
   echo  "            'local' for a local repository, or 'remote' to download"
   echo  "            the last created tar.gz [internal use only]"
   echo  "NOTE: Refer to the companion ReadMe.txt file for instructions."
   exitCode
}

# ##############################################################################
# getOS()   Determines the OS and in the case of Linux, the Linux distro
# ##############################################################################
getOS() {
   echo Detecting OS...

   case `uname -s` in
   AIX)
      _OS="AIX"
      _DISTRO="IBM"
      _OSLEVEL=`oslevel -s`
      _OS_VERSION=`echo "scale=1; $(echo $_OSLEVEL | cut -d'-' -f1)/1000" | bc`
      ;;

   Linux)
      _OS="Linux"
      if [ -f /etc/redhat-release ] ; then
         _DISTRO="RedHat"
         _OS_VERSION=`cat /proc/version`

         # Test if this is CentOS
         _TEMP_OS=`cat /etc/redhat-release | grep 'CentOS'`
         # If this is a CentOS, RC = 0
         _RC1=$?
         # Test if this is some other RedHat Linux
         _TEMP_OS=`cat /etc/redhat-release | grep 'Hat'`
         # If this is Red Hat, RC = 0
         _RC2=$?
         # Test if this is RedHat Enterprise Linux
         _TEMP_OS=`cat /etc/redhat-release | grep 'Hat Enterprise'`
         # If this is Red Hat Enterprise, RC = 0
         _RC3=$?
         _TEMP_OS=`cat /etc/issue.net | head -1 | grep 'Oracle'`
         # If this is Oracle Enterprise Linux, RC = 0
         _RC4=$?
         # If this is OEL, RC = 0
         _TEMP_OS=`uname -a | grep 's390x'`
         # If this is 64 bit zLinux, RC = 0
         _RC5=$?
         # If this is zLinux, RC = 0

         if [ "$_RC1" == "0" ] ; then
            _DISTRO_NAME="CentOS Linux"
         elif [ "$_RC5" == "0" ] ; then
            _DISTRO_NAME="zLinux s390x"
         elif [ "$_RC4" == "0" ] ; then
            _DISTRO_NAME="Oracle Enterprise Linux"
         elif [ "$_RC3" == "0" ] ; then
            _DISTRO_NAME="Red Hat Enterprise Linux"
         elif [ "$_RC2" == "0" ] ; then
            _DISTRO_NAME="Red Hat Linux"
         else
            _DISTRO_NAME="Red Hat (variant) Linux"
         fi

         if grep -q -i "release 4" /etc/redhat-release ; then
            _MAJOR_RELEASE=4
         elif grep -q -i "release 5" /etc/redhat-release ; then
            _MAJOR_RELEASE=5
         elif grep -q -i "release 6" /etc/redhat-release ; then
            _MAJOR_RELEASE=6
         elif grep -q -i "release 7" /etc/redhat-release ; then
            _MAJOR_RELEASE=7
         elif grep -q -i "release 8" /etc/redhat-release ; then
            _MAJOR_RELEASE=8
         fi
      elif [ -f /etc/SuSE-release ] ; then
         _DISTRO="SuSE"
         _OS_VERSION=`cat /proc/version`

         # Test if this is Novell
         _TEMP_OS=`cat /etc/SuSE-release | grep 'Novell'`
         # If this is a Novell, RC = 0
         _RC1=$?
         # Test if this is OpenSuSE
         _TEMP_OS=`cat /etc/SuSE-release | grep 'openSUSE'`
         # If this is OpenSuSE, RC = 0
         _RC2=$?
         _TEMP_OS=`uname -a | grep 's390x'`
         # If this is 64 bit zSUSE, RC = 0
         _RC3=$?

         if [ "$_RC1" == "0" ] ; then
            _DISTRO_NAME="Novell SuSE Linux"
         elif [ "$_RC2" == "0" ] ; then
            _DISTRO_NAME="OpenSUSE"
         elif [ "$_RC3" == "0" ] ; then
            _DISTRO_NAME="zSUSE s390x"
         else
            _DISTRO_NAME="SuSE (variant) Linux"
         fi

         if grep -q -i "VERSION = 7" /etc/SuSE-release ; then
            _MAJOR_RELEASE=7
         elif grep -q -i "VERSION = 8" /etc/SuSE-release ; then
            _MAJOR_RELEASE=8
         elif grep -q -i "VERSION = 9" /etc/SuSE-release ; then
            _MAJOR_RELEASE=9
         elif grep -q -i "VERSION = 10" /etc/SuSE-release ; then
            _MAJOR_RELEASE=10
         elif grep -q -i "VERSION = 11" /etc/SuSE-release ; then
            _MAJOR_RELEASE=11
         elif grep -q -i "VERSION = 12" /etc/SuSE-release ; then
            _MAJOR_RELEASE=12
         elif grep -q -i "VERSION = 13" /etc/SuSE-release ; then
            _MAJOR_RELEASE=13
         fi
      elif [ -f /etc/mandrake-release ] ; then
         _DISTRO='Mandrake'
         _DISTRO_NAME="Mandrake Linux"
      elif [ -f /etc/debian_version ] ; then
         _DISTRO="Debian"
         _OS_VERSION=`cat /etc/debian_version`
         _MAJOR_RELEASE=`lsb_release -rs | cut -f1 -d.`

          # Test if this is an Ubuntu OS
         _TEMP_OS=`lsb_release -a`
         `grep -q "Ubuntu" <<< "${_TEMP_OS}"`
         # If this is a Ubuntu OS, RC = 0
         _RC1=$?
         # Test if this is an Debian OS
         `grep -q "Debian" <<< "${_TEMP_OS}"`
         # If this is a Debian OS, RC = 0
         _RC2=$?
         if [ "$_RC1" = "0" ] ; then
            _DISTRO_NAME="Ubuntu Linux"
         elif [ "$_RC2" = "0" ] ; then
            _DISTRO_NAME="Debian Linux"
         else
            _DISTRO_NAME="Debian (variant) Linux"
         fi
      fi
      ;;

   *)
      _OS="Unknown"
      _RC=1
      ;;

   esac

   echo COMPUTERNAME:  ${HOSTNAME}
   echo Detected OS:   ${_OS}
   echo Distribution:  ${_DISTRO}
   if [ "${_OS}" == "Linux" ]; then
      echo Distro Name:   ${_DISTRO_NAME}
      echo Major Release: ${_MAJOR_RELEASE}
   fi
}

# ##############################################################################
# getParm    Determines a particular parameter by looking at _PARM
# ##############################################################################
getParm() {
   if [ "${_DEBUG}" == "1" ]; then
      echo Processing parameters: ${_PARM} and ${_PARM_VALUE}
   fi

   if [ -z "${_PARM}" ]; then
      _RC=99
   fi

   _RC=0
   case "$_PARM" in
   --hel)
      _ACTION=help
      displaySyntax
      ;;
   --help)
      _ACTION=help
      displaySyntax
      ;;
   --ins)
      _ACTION=install
      ;;
   --install)
      _ACTION=install
      ;;
   --con)
      _ACTION=console
      ;;
   --console)
      _ACTION=console
      ;;
   --jav)
      _ACTION=java
      ;;
   --java)
      _ACTION=java
      ;;
   --sta)
      _ACTION=status
      ;;
   --status)
      _ACTION=status
      ;;
   *)
      if [ -z "${_PARM_VALUE}" ]; then
        echo ERROR: Parameters are 3 characters and require a value [--par value]. Found ${_PARM}.
        _RC=99
        exitCode
      fi

      _PARM_VALUE_BOOL=1
      case "$_PARM" in
      --adm)
         _ADMIN=${_PARM_VALUE}
         ;;
      --com)
         _SOA_COMPONENT=${_PARM_VALUE}
         _PARM_VALUE_BOOL=0
         ;;
      --deb)
         _DEBUG=${_PARM_VALUE}
         ;;
      --del)
         _DELETE=${_PARM_VALUE}
         ;;
      --dow)
         _DOWNLOAD=${_PARM_VALUE}
         ;;
      --jre)
         JRE_HOME=${_PARM_VALUE}
         _PARM_VALUE_BOOL=0
         ;;
      --jvm)
         JVM_PATH=${_PARM_VALUE}
         _PARM_VALUE_BOOL=0
         ;;
      --mer)
         _MERGE=${_PARM_VALUE}
         ;;
      --oje)
         JRE_HOME_OLD=${_PARM_VALUE}
         _PARM_VALUE_BOOL=0
         ;;
      --ojm)
         JVM_PATH_OLD=${_PARM_VALUE}
         _PARM_VALUE_BOOL=0
         ;;
      --roo)
         OPTIM_ROOT=${_PARM_VALUE}
         export OPTIM_ROOT
         ;;
      --qua)
         _SOA_QUALIFIER=${_PARM_VALUE}
         _PARM_VALUE_BOOL=0
         ;;
      --upd)
         _UPDATE=${_PARM_VALUE}
         ;;
      --kee)
         _KEEP=${_PARM_VALUE}
         ;;
      --unv)
         MAJOR_UNSTALL_VERSION=${_PARM_VALUE}
         export MAJOR_UNSTALL_VERSION
         _PARM_VALUE_BOOL=0
         ;;
      --url)
         _URL=${_PARM_VALUE}
         _PARM_VALUE_BOOL=0
         ;;
      --use)
         _USE_EXISTING=${_PARM_VALUE}
         ;;
      --ver)
         _SOA_VER=${_PARM_VALUE}
         _PARM_VALUE_BOOL=0
         ;;
      *)
         echo ${_PARM} is an unrecognized parameter.
         _RC=99
         exitCode
         ;;
      esac
   
      if [ "${_PARM_VALUE_BOOL}" == "1" ] ; then
         if [ "${_PARM_VALUE}" == "1" ] ; then
            _RC=0  
         elif [ "${_PARM_VALUE}" == "0" ] ; then
            _RC=0 
         else
            echo ${_PARM} requires a value of 0 or 1, found ${_PARM_VALUE}.
            _RC=99
            exitCode
         fi
      fi
      ;;
   esac

}

# ##############################################################################
# getParms    Determines the parameters
# ##############################################################################
getParms() {
   if [ -z "$1" ] ; then
      displaySyntax
   fi
   
   while (( "$#" ));
   do
      if [ "${_DEBUG}" == "1" ] ; then
         echo ARGUMENTS: $1 $2 $3 $4 $5 $6 $7 $8 $9 ${10} ${11} ${12} ${13} ${14} ${15} ${16} ${17} ${18} ${19} ${20} ${21}
      fi 
      
      if [ ! -z "$1" ] ; then
         _PARM=$1
         _PARM_VALUE=""
         case "$_PARM" in
         --con) shift ;;
         --console) shift ;;
         --hel) shift ;;
         --help) shift ;;
         --ins) shift ;;
         --install) shift ;;
         --jav) shift ;;
         --java) shift ;;
         --sta) shift ;;
         --status) shift ;;
         *)
            if [[ ! -z "$2" ]] && [[ ! "$2" == "--"* ]] ; then
               _PARM_VALUE=$2
               shift
               shift
            else
              shift
            fi
            ;;
         esac
         getParm
      fi
   done
}

# ##############################################################################
# updateFile  Update a file
# ##############################################################################
updateFile() {

   if [ -z ${_SEARCH} ] ; then
      echo ERROR: A search argument is required.
      _RC=99
      exitCode
   fi
   if [ -z ${_REPLACE} ] ; then
      echo ERROR: A replace argument is required.
      _RC=99
      exitCode
   fi
   if [ -z ${_FILE} ] ; then
      echo ERROR: A file argument is required.
      _RC=99
      exitCode
   fi

   echo Updating file ${_FILE} ...
   echo "   Replace ${_SEARCH}"
   echo "   with    ${_REPLACE}"
   ${_SED} -i "s;${_SEARCH};${_REPLACE};1" "${_FILE}"
}

# ##############################################################################
# updateEclipseINI  Update an eclipse.ini file
# ##############################################################################
updateEclipseINI() {
   # Always update the JVM before JRE_HOME as the JRE_HOME may be a substring of the JVM
   _SEARCH=${JVM_PATH_OLD}
   _REPLACE=${JVM_PATH}
   _FILE=${_ECLIPSE_INI}
   updateFile
}

# ##############################################################################
# updateOptimProperties  Update the optim.properties file
# ##############################################################################
updateOptimProperties() {
   # Always update the JVM before JRE_HOME as the JRE_HOME may be a substring of the JVM
   _SEARCH=${JVM_PATH_OLD}
   _REPLACE=${JVM_PATH}
   _FILE=${_OPTIM_PROPERTIES}
   updateFile
   _SEARCH=${JRE_HOME_OLD}
   _REPLACE=${JRE_HOME}
   _FILE=${_OPTIM_PROPERTIES}
   updateFile
}

# ##############################################################################
# updateOptimConfigPST  Update the OptimConfig*.pst files
# ##############################################################################
updateOptimConfigPST() {
   # There are 2 .pst files
   PSTFiles=(${_OPTIM_CONFIG_CLIENT_PST} ${_OPTIM_CONFIG_SERVER_PST})   
   for theFile in ${PSTFiles[@]}
      do
         if [ -f ${theFile} ] ; then
            _FILE=${theFile}
            _SEARCH=${JVM_PATH_OLD}
            _REPLACE=${JVM_PATH}
		    updateFile
            _SEARCH=${JRE_HOME_OLD}
            _REPLACE=${JRE_HOME}
            updateFile
		fi
      done
}

# ##############################################################################
# updateRtSetJVM  Update the rtsetjvm file
# ##############################################################################
updateRtSetJVM() {
   # Always update the JVM before JRE_HOME as the JRE_HOME may be a substring of the JVM
   _SEARCH=${JVM_PATH_OLD}
   _REPLACE=${JVM_PATH}
   _FILE=${_RTSETJVM}
   updateFile
   _SEARCH=${JRE_HOME_OLD}
   _REPLACE=${JRE_HOME}
   _FILE=${_RTSETJVM}
   updateFile
}

# ##############################################################################
# updateSetJRE  Update the set_jre file
# ##############################################################################
updateSetJRE() {
   # Always update the JVM before JRE_HOME as the JRE_HOME may be a substring of the JVM
   _SEARCH=${JRE_HOME_OLD}
   _REPLACE=${JRE_HOME}
   _FILE=${_SET_JRE}
   updateFile
}

# ##############################################################################
# updateJava  Update the JRE_HOME and JVM_PATH settings for a component
# ##############################################################################
updateJava() {
   # Clear out the eclipse.ini location for Runtime
   _ECLIPSE_INI=""
   # Clear out the optim.properties location for Runtime  
   _OPTIM_PROPERTIES=""
   # Clear out the OptimConfigClient.pst location for Runtime
   _OPTIM_CONFIG_CLIENT_PST=""
   # Clear out the OptimConfigServer.pst location for Runtime
   _OPTIM_CONFIG_SERVER_PST=""
   # Clear out the the rtsetjvm location for Runtime
   _RTSETJVM=""
   # Clear out the set_jre location for Web Applications
   _SET_JRE=""

   case "${_SOA_COMPONENT}" in
   runtime)
      _ECLIPSE_INI=${OPTIM_ROOT}/services/eclipse.ini
      _OPTIM_PROPERTIES=${OPTIM_ROOT}/rt/optim.properties
      _OPTIM_CONFIG_CLIENT_PST=${OPTIM_ROOT}/rt/OptimConfigClient.pst
      _OPTIM_CONFIG_SERVER_PST=${OPTIM_ROOT}/rt/OptimConfigServer.pst
      _RTSETJVM=${OPTIM_ROOT}/rt/rtsetjvm
	  mandatoryFiles=(${_ECLIPSE_INI} ${_OPTIM_PROPERTIES} ${_OPTIM_CONFIG_CLIENT_PST} ${_OPTIM_CONFIG_SERVER_PST} ${_RTSETJVM})
	  
	  for theFile in ${mandatoryFiles[@]}
         do
            echo Validating ${theFile} ... 
            if [ ! -f ${theFile} ] ; then
               echo ERROR: The file ${theFile}, used by Optim Runtime Services, can not be found.
               _RC=2
            fi
		 done
      if [ ${_RC} == 2 ] ; then
         exitCode
	  fi
      export _ECLIPSE_INI _OPTIM_PROPERTIES _OPTIM_CONFIG_CLIENT_PST _OPTIM_CONFIG_SERVER_PST _RTSETJVM 
      ;;
   test)
      _ECLIPSE_INI=${OPTIM_ROOT}/test/eclipse.ini
      echo Validating ${_ECLIPSE_INI} ... 
      if [ ! -f ${_ECLIPSE_INI} ] ; then
         echo ERROR: The file ${_ECLIPSE_INI}, used for Optim Testing, can not be found.
         _RC=2
         exitCode
      fi
      export _ECLIPSE_INI
      ;;
   web)
      _SET_JRE=${OPTIM_ROOT}/shared/web/setup/set_jre
      echo Validating ${_SET_JRE} ... 
      if [ ! -f ${_SET_JRE} ] ; then
         echo ERROR: The file ${_SET_JRE}, used by Optim Web Applications, can not be found.
         _RC=2
         exitCode
      fi
      export _SET_JRE
      ;;
   *)
      echo ERROR: The component name ${_SOA_COMPONENT} is not runtime or web.
      _RC=11
      exitCode
      ;;
   esac

   displayCommand

   # ##############################################################################
   # startUpdate Start of update processing
   # ##############################################################################

   if [ "${_SOA_COMPONENT}" == "runtime" ] ; then
      updateEclipseINI
      updateOptimProperties
      updateOptimConfigPST
      updateRtSetJVM
   elif [ "${_SOA_COMPONENT}" == "test" ] ; then
      updateEclipseINI
   elif [ "${_SOA_COMPONENT}" == "web" ] ; then
      updateSetJRE
   else
      echo The component name ${_SOA_COMPONENT} is not runtime or web.
      _RC=11
      exitCode
   fi
   exitCode
}

# ##############################################################################
# validateEnvironment  Validate the environment
# ##############################################################################
validateEnvironment() {
   echo Validating the environment ...

   if [ -z ${_SOA_COMPONENT} ] ; then
      echo ERROR: The parameter --com[ponent] and a component name of runtime or web are required.
      _RC=4
      exitCode
   elif [ -z ${_SOA_VER} ] ; then
      echo ERROR: The four digit Optim version, _SOA_VER, is required
      echo either as a parameter -ver [OPTIM VERSION] or
      echo as a variable in the file ${_DIR}/optimsetenv.sh.
      _RC=5
      exitCode
   fi

   case "${_SOA_COMPONENT}" in
   runtime)
      ;;
   test)
      # Internal Use Only
      ;;
   web)
      ;;
   *)
      echo ERROR: --com[ponent] must be runtime or web.
      _RC=4
      exitCode
      ;;
   esac

   if [ -z ${_HOME} ]; then
      echo ERROR: The environment variable _HOME must be specified
      echo as a variable in the file ${_DIR}/optimsetenv.sh.
      _RC=8
      exitCode
   fi
   if [ ! -d ${_HOME} ]; then
      echo ERROR: The home directory ${_HOME}, as defined by _HOME, does not exist.
      _RC=8
      exitCode
   fi
   if [ -z ${OPTIM_ROOT} ]; then
      echo ERROR: The environment variable OPTIM_ROOT must be specified
      echo either as a parameter --roo [optim_root] or
      echo as a variable in the file ${_DIR}/optimsetenv.sh.
      _RC=8
      exitCode
   fi
   if [ ! -d ${OPTIM_ROOT} ]; then
      if [ "${_ACTION}" == "java" ] ; then
         echo ERROR: The Optim Root directory ${OPTIM_ROOT}, as defined by OPTIM_ROOT, does not exist.
         _RC=7
         exitCode
      else
         echo WARNING: The Optim Root directory ${OPTIM_ROOT}, as defined by OPTIM_ROOT, does not exist.
      fi
   fi

   if [ -z ${_ROOT_DIR} ]; then
      echo ERROR: _ROOT_DIR must be specified
      echo as a variable in the file ${_DIR}/optimsetenv.sh.
      _RC=8
      exitCode
   fi
   if [ ! -d ${_ROOT_DIR} ]; then
      echo ERROR: The root directory ${_SCRIPTS_DIR}, as defined by _SCRIPTS_DIR, does not exist.
      echo It should be set to the directory of this shell script.
      _RC=8
      exitCode
   fi
   if [ ! -f ${_ROOT_DIR}/optimutil.sh ]; then
      echo ERROR: The root directory ${_ROOT_DIR}, as defined by _ROOT_DIR, does not contain the optimutil shell script.
      echo It should be set to the directory of this shell script.
      _RC=8
      exitCode
   fi
   if [ -z ${_SCRIPTS_DIR} ]; then
      echo ERROR: _SCRIPTS_DIR must be specified
      echo as a variable in the file ${_DIR}/optimsetenv.sh.
      _RC=8
      exitCode
   fi
   if [ ! -d ${_SCRIPTS_DIR} ]; then
      echo ERROR: The scripts directory ${_SCRIPTS_DIR}, as defined by _SCRIPTS_DIR, does not exist.
      _RC=8
      exitCode
   fi
   if [ ! -f ${_SCRIPTS_DIR}/SilentInstall.sh ]; then
      echo ERROR: The scripts directory ${_SCRIPTS_DIR}, as defined by _SCRIPTS_DIR, does not contain the SilentInstall.sh script file.
      echo It should be set to the directory of the companion shell scripts and XML files.
      _RC=8
      exitCode
   fi

   if [ -z ${JRE_HOME} ]; then
      echo ERROR: The environment variable JRE_HOME must be specified
      echo either as a parameter --jre [JRE_HOME] or
      echo as a variable in the file ${_DIR}/optimsetenv.sh.
      _RC=7
      exitCode
   fi
   if [ ! -d ${JRE_HOME} ]; then
      echo ERROR: The JRE_HOME directory ${JRE_HOME}, does not exist.
      _RC=7
      exitCode
   fi
   if [ ! -f ${JRE_HOME}/bin/java ]; then
      echo ERROR: The java executable file ${JRE_HOME}/bin/java, does not exist.
      echo Ensure that the variable JRE_HOME does not include the jre directory.
      _RC=7
      exitCode
   fi

   if [ -z ${JVM_PATH} ]; then
      echo ERROR: The environment variable JVM_PATH must be specified
      echo either as a parameter --jvm [JVM_PATH] or
      echo as a variable in the file ${_DIR}/optimsetenv.sh.
      _RC=11
      exitCode
   fi
   if [ ! -f ${JVM_PATH} ]; then
      echo ERROR: The file ${JVM_PATH}, as defined by JVM_PATH, does not exist.
      _RC=7
      exitCode
   fi
   if [[ ! "${JVM_PATH}" == *"libjvm.so" ]]; then
      echo ERROR: The JVM path ${JVM_PATH}, as defined by JVM_PATH, must point to the libjvm.so file.
      _RC=7
      exitCode
   fi

   if [ "${_ACTION}" == "java" ] ; then
      # The old JRE may have been uninstalled, so only validate that the variable exist
      if [ -z ${JRE_HOME_OLD} ]; then
         echo ERROR: The environment variable JRE_HOME_OLD must be specified
         echo either as a parameter --oje [JRE_HOME_OLD] or
         echo as a variable in the file ${_DIR}/optimsetenv.sh.
         _RC=10
         exitCode
      fi
      if [ -z ${JVM_PATH_OLD} ]; then
         echo ERROR: The environment variable JVM_PATH_OLD must be specified
         echo either as a parameter --ojm [JVM_PATH_OLD] or
         echo as variable in the file ${_DIR}/optimsetenv.sh.
         _RC=12
         exitCode
      fi
      if [[ ! "${JVM_PATH_OLD}" == *"libjvm.so" ]]; then
         echo ERROR: The old JVM path ${JVM_PATH_OLD}, as defined by JVM_PATH_OLD, must point to the old libjvm.so file.
         _RC=12
         exitCode
      fi
 
      if [ "${JRE_HOME}" == "${JRE_HOME_OLD}" ]; then
         echo WARNING: The values for the environment variables JRE_HOME and JRE_HOME_OLD are identical.
         _RC=13
      fi

      if [ "${JVM_PATH}" == "${JVM_PATH_OLD}"  ]; then
         echo WARNING: The values for the environment variables JVM_PATH and JVM_PATH_OLD are identical.
         _RC=13
      fi
   fi
   if [ "${_ACTION}" == "install" ] ; then
      if [ "${_DOWNLOAD}." == ".1" ] ; then
         if [ ! -f "${_WGET}" ] ; then
            echo Can not find ${_WGET}
            _RC=6
            exitCode
          fi
         if [ ! -f "${_ZIP}" ] ; then
            echo Can not find ${_ZIP}
            _RC=6
            exitCode
         fi
   
         if [ -z ${_URL} ] ; then
            echo The parameter --url and a value are required.
            _RC=3
            exitCode
         fi
         if [ "${_USE_EXISTING}" == "1" ] ; then
            echo The parameter --dow[load] 1 is not permitted with --use[ existing] 1.
            _RC=10
            exitCode
         fi
      fi
   fi
}

# ##############################################################################
# validateIMEnvironment    Validates the Installation Manager environment
# ##############################################################################
validateIMEnvironment() {
   echo Validating the Installation Manager environment
   if [ -z "${_ADMIN}" ] ; then
      echo ERROR: The environment variable _ADMIN, which defines how Installation Manager was installed, must be set
      echo either as a parameter --adm [1=adminstrator or 0=user] or
      echo as variable in the file ${_DIR}/optimsetenv.sh.
      _RC=20
      exitCode
   fi
   _UUID=$(id -u)
   if [ "${_UUID}" == "0" ] ; then
      if [ "${_ADMIN}" == "0" ] ; then
         echo WARNING: The current user has a UID of ${_UUID} with administrator privileges, but is being used to run Installation Manager without administrator privileges.
         echo Use --adm 1 to run Installation Manager with administrator privileges.
     fi
   else
      if [ "${_ADMIN}" == "1" ] ; then
         echo ERROR: The current user has a UID of ${_UUID} without administrator privileges, but is being used to run Installation Manager as an administrator.
         echo Use --adm 0 to run Installation Manager without administrator privileges.
         _RC=20
         exitCode
     fi
   fi

   if [ -z "${IM_ROOT}" ] ; then
      echo ERROR: The environement variable IM_ROOT must be set to the IBM Installation Manager eclipse directory
      echo in the file ${_DIR}/optimsetenv.sh.
      _RC=20
      exitCode
   elif [ ! -d "${IM_ROOT}" ] ; then
      echo ERROR: The IBM Installation Manager eclipse directory ${IM_ROOT}, as defined by IM_ROOT, not found.
      _RC=20
      exitCode
   elif [ -z "${_IM_TOOL}" ] ; then
      echo ERROR: The environement variable _IM_TOOL must be set to the IBM Installation Manager imcl program in the tools directory
      echo in the file ${_DIR}/optimsetenv.sh.
      _RC=20
      exitCode
   elif [ ! -f "${_IM_TOOL}" ] ; then
      echo ERROR: The IBM Installation Manager tools program ${_IM_TOOL}, as defined by _IM_TOOL, not found.
      _RC=20
      exitCode
   elif [ -z "${IM_INSTALL_MODE}" ] ; then
      echo IM_INSTALL_MODE must be set to admin or nonAdmin.
      echo Specify --adm 1 to install as an administrator or --adm 0 to install as a non-administror user.
      _RC=20
      exitCode
   fi
}

# START
# Reset all variables
declare -a _FILE_LIST=("_ACTION" "_ADMIN" "_COMPONENT_DIR" "_COPY_FILE_LIST" "_DEBUG" "_DELETE" "_DIR" "_DOWNLOAD" "_FART" "_IM_TOOL" "_INSTALL" "_INSTALLER" "_INTERNAL" "_JENKINS_DIR" "_KEEP" "_LINE" "_MERGE" "_OFFERING" "_PARM_VALUE_BOOL" "_PERFORM" "_PROJECT_DIR" "_PROJECT_FILE" "_PROJECT_ROOT" "_RC" "_REPO" "_ROOT_DIR" "_SCRIPTS_DIR" "_SHARED_DIR" "_SOA_COMPONENT" "_SOA_QUALIFIER" "_SOA_VER" "_TAR" "_TAR_GZ" "_THIS_SCRIPT" "_UNINSTALL_SHARED_XML" "_UPDATE" "_URL" "_USE_EXISTING" "_WGET" "_ZIP" "_ECLIPSE_INI" "_OPTIM_PROPERTIES" "_OPTIM_CONFIG_CLIENT_PST" "_OPTIM_CONFIG_SERVER_PST" "_RTSETJVM")
for f in "${_FILE_LIST[@]}"
do
   unset ${f}
done

# Get the current directory if it is not already set
_DIR=${_DIR:-$(dirname $0)}

# Save the name of this script in case it is destroyed later
_THIS_SCRIPT=$0

getOS

# Does a file exists that sets up all the defaults
if [ -f ${_DIR}/optimsetenv.sh ] ; then
   chmod +x ${_DIR}/optimsetenv.sh
   echo Loading local environment variables from ${_DIR}/optimsetenv.sh.
   source ${_DIR}/optimsetenv.sh
else
   echo local environment variables file ${_DIR}/optimsetenv.sh not found.
   _RC=2
   exitCode
fi

# You can download wget from www.gnu.org
_WGET=${_WGET:-/usr/bin/wget}
# You can download Jenkins from https://jenkins.io, or use you own automation server
_ROOT_DIR=${_ROOT_DIR:-"${HOME}/Jenkins"}
_SCRIPTS_DIR=${_SCRIPTS_DIR:-"${_ROOT_DIR}/scripts"}
# You can download the GNU tar from www.gnu.org
_ZIP=${_ZIP:-"/usr/bin/tar"}
# For SuSE tar is located in /bin
if [ "${_OS}" == "Linux" ] ; then
   if [ "${_DISTRO}" == "SuSE" ] ; then
      _ZIP=${_ZIP:-"/bin/tar"}
   fi
fi

# SED (Stream EDitor) is typically part of the base OS installation
_SED=${_SED:-"/usr/bin/sed"}
# The IBM Installation Manager sub directory part
IM_ROOT=${IM_ROOT:-"${HOME}/IBM/InstallationManager/eclipse"}
# The location of the Installation Manager command line tool
_IM_TOOL=${IM_ROOT}/tools/imcl
_MAX_RC=${_MAX_RC:-0}
MAJOR_UNINSTALL_VERSION=${MAJOR_UNINSTALL_VERSION:-"11.3.0.0"}
export _SED IM_ROOT _IM_TOOL _MAX_RC MAJOR_UNINSTALL_VERSION
# This will be set later in this script file.
_REPO_DIR=
# Ensure ${_RC} contains the last return code
_RC=${_RC:-0}
_DOWNLOAD=${_DOWNLOAD:-0}
_INSTALL=${_INSTALL:-1}
_DELETE=${_DELETE:-0}
_UPDATE=${_UPDATE:-0}
_MERGE=${_MERGE:-0}
_KEEP=${_KEEP:-1}
_USE_EXISTING=${_USE_EXISTING:-1}
_SOA_QUALIFIER=${_SOA_QUALIFIER:-"local"}
_SOA_VER=${_SOA_VER:-"11700"}
# Set _ADMIN=1 sets IM installMode to admin, otherwise nonAdmin
_ADMIN=${_ADMIN:-0}
# Optional: Location of an internal web server that contains the installer tar.gz file
_URL=${_URL:-""}
_DEBUG=${_DEBUG:-0}
# Is set to 1 only if --ins 1, --upd 1, or --del 1 is specified.
_PERFORM=0

# Default to running the installer in silent mode
_ACTION=install

if [ "${_DEBUG}" == "1" ] ; then
   echo .
   echo Command line: ${_THIS_SCRIPT} $1 $2 $3 $4 $5 $6 $7 $8 $9 ${10} ${11} ${12} ${13} ${14} ${15} ${16} ${17} ${18} ${19} ${20} ${21} ${22} ${23}
   echo .
fi 

getParms $1 $2 $3 $4 $5 $6 $7 $8 $9 ${10} ${11} ${12} ${13} ${14} ${15} ${16} ${17} ${18} ${19} ${20} ${21} ${22} ${23}
if [ "${_DEBUG}" == "1" ] ; then
   echo Parsing complete.
   echo .
fi 

# Set to admin or nonAdmin mode, depending on how Installation Manager is installed 
if [ ${_ADMIN} == 0 ] ; then
   IM_INSTALL_MODE=nonAdmin
else
   IM_INSTALL_MODE=admin
fi
export IM_INSTALL_MODE

# Ensure Installation Manager related variables are defined correctly
validateIMEnvironment

if [ "${MAJOR_UNINSTALL_VERSION}" != "11.3.0.0" ] ; then
   if [ "${MAJOR_UNINSTALL_VERSION}" != "11.7.0.0" ] ; then
      if [ "${UNINSTALL_RUNTIME}" == "1" ] ; then
         echo MAJOR_UNINSTALL_VERSION must be 11.3.0.0 or 11.7.0.0.
         _RC=99
         exit ${_RC}
      elif [ "${UNINSTALL_SHARED}" == "1" ] ; then
         echo MAJOR_UNINSTALL_VERSION must be 11.3.0.0 or 11.7.0.0, found: $MAJOR_UNINSTALL_VERSION.
         _RC=99
         exit ${_RC}
      fi
   fi
fi

if [ "${MAJOR_UNINSTALL_VERSION}" == "11.3.0.0" ] ; then
   declare -a _FILE_LIST=("installRuntime.xml" "installShared.xml" "uninstallRuntime.xml" "uninstallShared11300.xml" "OptimSilentUninstall.sh" "SilentInstall.sh")
   _UNINSTALL_SHARED_XML=uninstallShared11300.xml
elif [ "${_INTERNAL}" == "1" ] ; then
   _UNINSTALL_SHARED_XML=uninstallShared.xml
   export _UNINSTALL_SHARED_XML
   # Internal Use Only
   declare -a _FILE_LIST=("installRuntime.xml" "installShared.xml" "installTest.xml" "uninstallRuntime.xml" "uninstallShared.xml" "uninstallTest.xml" "SilentInstall.sh")
   declare -a _FILE_LIST_JAVA=("installSharedJava.xml" "uninstallSharedJava.xml" "SilentInstall.sh")
else
   _UNINSTALL_SHARED_XML=uninstallShared.xml
   export _UNINSTALL_SHARED_XML
   declare -a _FILE_LIST=("installRuntime.xml" "installShared.xml" "uninstallRuntime.xml" "uninstallShared.xml" "SilentInstall.sh")
fi

if [ "${_ACTION}." == "status." ] ; then
   displayStatus
fi

if [ "${_ACTION}." == "console." ] ; then
   if [ "${_DELETE}." == "1." ] ; then
      _DELETE=0
      export DELETE
      echo The option --del[ete] 1 is not permitted with --console and will be ignored.
   fi
   if [ "${_UPDATE}." == "1." ] ; then
      _UPDATE=0
      export _UPDATE
      echo The option --upd[ate] 1 is not permitted with --console and will be ignored.
   fi
   if [ "${_DOWNLOAD}." == "1." ] ; then
      _DOWNLOAD=0
      export _DOWNLOAD
      echo The option --dow[nload] 1 is not permitted with --console and will be ignored.
   fi 
fi

if [ "${_ACTION}." == "console." ] ; then
   consoleInstall
fi

# The remaining actions require a component
validateEnvironment

if [ "${_ACTION}." == "java." ] ; then
   updateJava
fi


if [ "${_ACTION}." == "install." ] ; then
   if [ "${_DELETE}." == "1." ] ; then
      _INSTALL=0
   elif [ "${_DELETE}." == "0." ] ; then
      _INSTALL=1
   fi
   if [ "${_DELETE}." == "1." ] ; then
      _INSTALL=0
   fi
fi

if [ "${_DEBUG}" == "1" ] ; then
   echo .
   echo _SOA_QUALIFIER is ${_SOA_QUALIFIER}.
   echo .
fi 

if [ "${_DELETE}." == "1." ] ; then
   if [ "${_UPDATE}." == "1." ] ; then
      echo The parameter --upd[date] 1 is not permitted with --del[ete] 1.
      exit 10
   fi 
   if [ "${_DOWNLOAD}." == "1." ] ; then
      echo The parameter --dow[nload] 1 is not permitted with --del[ete] 1.
      exit 10
   fi 
fi

displayCommand

if [ "${_SOA_QUALIFIER}." == "remote." ] ; then
   _PROPERTIES_URL=${_URL}/latestBuild${_SOA_VER}.properties
   _PROPERTIES_FILE=${_SCRIPTS_DIR}/latestBuild${_SOA_VER}.properties

   echo The parameter --qua[lifier] was not specified. Obtaining qualifier from ${_PROPERTIES_FILE}

   echo Validating ${_PROPERTIES_URL}
   #  2>&1 findstr /C:"HTTP/1.1 200"
   ${_WGET} -S --spider "${_PROPERTIES_URL}"
   _RC=$?
   if [ ${_RC} -gt ${_MAX_RC} ] ; then
      echo File ${_PROPERTIES_URL} not found.
      _RC=7
      exitCode
   fi
   
   # Remove previously downloaded properties file
   if [ -f ${_PROPERTIES_FILE} ] ; then rm -f  ${_PROPERTIES_FILE}; fi

   echo Downloading ${_PROPERTIES_URL}
   ${_WGET} -nd -P${_SCRIPTS_DIR} ${_PROPERTIES_URL}
   _RC=$?
   if [ ${_RC} -gt ${_MAX_RC} ] ; then
      echo Failed to download ${_PROPERTIES_URL}.
      _RC=8
      exitCode
   fi
   
   if [ "${_DEBUG}" == "1" ] ; then
      echo .
      echo START: Reading ${_PROPERTIES_FILE}
      echo .
   fi 

   while read p; do
      if [ "${_DEBUG}" == "1" ] ; then
         echo .
         echo LINE: ${p}
         echo .
      fi 

     if [[ "${p}" == "latestBuild.${_SOA_COMPONENT}.ver"* ]] ; then
        # Strip everything up to and including the '='
        _SOA_QUALIFIER=${p#*=}
        echo Found a QUALIFIER of ${_SOA_QUALIFIER} for ${_SOA_COMPONENT}
     elif [[ "${p}" == "latestBuild.${_SOA_COMPONENT}.zip"* ]] ; then
        # Strip everything up to and including the '='
        _INSTALLER=${p#*=}
        echo Found a TAR File of ${_INSTALLER} for ${_SOA_COMPONENT}
        break
     fi
   done < ${_PROPERTIES_FILE}

   if [ "${_DEBUG}" == "1" ] ; then
      echo .
      echo FINISHED: Reading ${_PROPERTIES_FILE}
      echo .
   fi 

   if [ -z ${_SOA_QUALIFIER} ] ; then
      echo The parameter --qua[lifier] was not specified and was not found in ${_PROPERTIES_FILE}
      _RC=9
      exitCode
   elif [ -z ${_INSTALLER} ] ; then
      echo The parameter --qua[lifier] was not specified and the tar file was not found in ${_PROPERTIES_FILE}
      _RC=9
      exitCode
   fi
   if [[ ${_INSTALLER} == *"_GA"* ]]; then
      _TAR_GZ=${_SOA_COMPONENT}${_SOA_QUALIFIER}_GA.tar.gz
   else
      _TAR_GZ=${_SOA_COMPONENT}${_SOA_QUALIFIER}.tar.gz
   fi
    # The properties in the file have the SOA_VER in the ver property
   _TAR=${_SOA_COMPONENT}${_SOA_QUALIFIER}.tar
elif [ "${_SOA_QUALIFIER}." == "local." ] ; then
   case "${_SOA_COMPONENT}" in
   runtime)
      _REPO_DIR=${OPTIM_FIXPACK_RUNTIME}
   ;;
   java)
      # Internal Use Only
      _REPO_DIR=${OPTIM_FIXPACK_JAVA}
   ;;
   test)
      # Internal Use Only
      _REPO_DIR=${OPTIM_FIXPACK_TEST}
   ;;
   wasce)
      _REPO_DIR=${OPTIM_FIXPACK_WASCE}
   ;;
   web)
      _REPO_DIR=${OPTIM_FIXPACK_WEB}
   ;;
   esac
   _COMPONENT_DIR=${_SCRIPTS_DIR}/${_SOA_COMPONENT}
else
   _TAR=${_SOA_COMPONENT}${_SOA_VER}_${_SOA_QUALIFIER}.tar
   _TAR_GZ=${_SOA_COMPONENT}${_SOA_VER}_${_SOA_QUALIFIER}.tar.gz
   _INSTALLER=${_URL}/${_SOA_COMPONENT}/${_SOA_VER}dev/${_TAR_GZ}
fi

if [ "${_DEBUG}" == "1" ] ; then
   echo .
   echo echo _INSTALLER: ${_INSTALLER}
   echo .
fi 

if [ "${_SOA_COMPONENT}" == "runtime" ] ; then
   _SHARED_DIR=${_SCRIPTS_DIR}/${_SOA_COMPONENT}
   _COMPONENT_DIR=${_SCRIPTS_DIR}/${_SOA_COMPONENT}
   if [ "${_USE_EXISTING}" == "1" ] ; then
      _REPO_DIR=${OPTIM_FIXPACK_RUNTIME}
   else
      _REPO_DIR=${_SCRIPTS_DIR}/${_SOA_COMPONENT}/repo
   fi
   if [ "${OPTIM_PERMANENT_LICENSE}" == "true" ] ; then
      if [ "${OPTIM_PERMANENT_DG_LICENSE}" == "true" ] ; then
         if [ ! -f "${OPTIM_PERMANENT_DG_LICENSE_DIRECTORY}/OPDG.LIC" ] ; then
            echo The Optim Data Growth License file ${OPTIM_PERMANENT_DG_LICENSE_DIRECTORY}/OPDG.LIC not found.
            _RC=15
            exitCode
         fi
      fi
      if [ "${OPTIM_PERMANENT_TDM_LICENSE}" == "true" ] ; then
         if [ ! -f "${OPTIM_PERMANENT_TDM_LICENSE_DIRECTORY}/OPTDM.LIC" ] ; then
            echo The Optim Test Data Management file ${OPTIM_PERMANENT_TDM_LICENSE_DIRECTORY}/OPTDM.LIC not found.
            _RC=15
            exitCode
         fi
      fi
      if [ "${OPTIM_PERMANENT_DP_LICENSE}" == "true" ] ; then
         if [ ! -f "${OPTIM_PERMANENT_DP_LICENSE_DIRECTORY}/OPDP.LIC" ] ; then
            echo The Optim Data Privacy License file ${OPTIM_PERMANENT_DP_LICENSE_DIRECTORY}/OPDP.LIC not found.
            _RC=15
            exitCode
         fi
      fi
   fi
elif [ "${_SOA_COMPONENT}" == "test" ] ; then
   _SHARED_DIR=${_SCRIPTS_DIR}/${_SOA_COMPONENT}
   _COMPONENT_DIR=${_SCRIPTS_DIR}/${_SOA_COMPONENT}
   if [ "${_USE_EXISTING}" == "1" ] ; then
      _REPO_DIR=${OPTIM_FIXPACK_TEST}
   else
      _REPO_DIR=${_SCRIPTS_DIR}/${_SOA_COMPONENT}/repo
   fi
elif [ "${_SOA_COMPONENT}" == "java" ] ; then
   _SHARED_DIR=${_SCRIPTS_DIR}/shared
   _COMPONENT_DIR=${_SCRIPTS_DIR}/shared/${_SOA_COMPONENT}
   if [ "${_USE_EXISTING}" == "1" ] ; then
      _REPO_DIR=${OPTIM_FIXPACK_JAVA}
   else
      _REPO_DIR=${_SCRIPTS_DIR}/shared/${_SOA_COMPONENT}/repo
   fi
elif [ "${_SOA_COMPONENT}" == "wasce" ] ; then
   _SHARED_DIR=${_SCRIPTS_DIR}/shared
   _COMPONENT_DIR=${_SCRIPTS_DIR}/shared/${_SOA_COMPONENT}
   if [ "${_USE_EXISTING}" == "1" ] ; then
      _REPO_DIR=${OPTIM_FIXPACK_WASCE}
   else
      _REPO_DIR=${_SCRIPTS_DIR}/shared/${_SOA_COMPONENT}/repo
   fi
elif [ "${_SOA_COMPONENT}" == "web" ] ; then
   _SHARED_DIR=${_SCRIPTS_DIR}/shared
   _COMPONENT_DIR=${_SCRIPTS_DIR}/shared/${_SOA_COMPONENT}
   if [ "${_USE_EXISTING}" == "1" ] ; then
      _REPO_DIR=${OPTIM_FIXPACK_WEB}
   else
      _REPO_DIR=${_SCRIPTS_DIR}/shared/${_SOA_COMPONENT}/repo
   fi
else
   echo The component name ${_SOA_COMPONENT} is not runtime or web.
   _RC=10
   exitCode
fi
if [ -z "${_COMPONENT_DIR}" ] ; then
   echo _COMPONENT_DIR not specified!
   _RC=11
   exitCode
else
   echo _COMPONENT_DIR=${_COMPONENT_DIR}
fi
if [ -z "${_REPO_DIR}" ] ; then
   echo _REPO_DIR not specified!
   _RC=11
   exitCode
else
   echo _REPO_DIR=${_REPO_DIR}
fi

if [ ! -d "${_SHARED_DIR}" ] ; then
   mkdir "${_SHARED_DIR}"
fi
if [ ! -d "${_COMPONENT_DIR}" ] ; then
   mkdir "${_COMPONENT_DIR}"
fi

if [ -f "${_SCRIPTS_DIR}/${_TAR_GZ}" ] ; then
   echo Tar.gz file ${_SCRIPTS_DIR}/${_TAR_GZ} was previously downloaded
elif [ "${_DOWNLOAD}" == "1" ] ; then
   if [ "${_USE_EXISTING}" == "1" ] ; then
      echo The parameter --dow[load] 1 can not be used with --use[existing] 1.
      _RC=11
      exitCode
   fi

   echo Validating ${_INSTALLER}
   #  2>&1 findstr /C:"HTTP/1.1 200"
   ${_WGET} -S --spider "${_INSTALLER}"
   _RC=$?
   if [ ${_RC} -gt ${_MAX_RC} ] ; then
      echo File ${_INSTALLER} not found.
      _RC=14
      exitCode
   fi

   # Remove all files in component directory UNLESS we are merging
   if [ "${_MERGE}" == "0" ] ; then
      rm -f -r ${_SHARED_DIR}/*.*
   fi

   echo Downloading ${_INSTALLER}
   ${_WGET} -nd -P${_SCRIPTS_DIR} ${_INSTALLER}
   _RC=$?
   if [ ${_RC} -gt ${_MAX_RC} ] ; then
      echo Failed to download ${_INSTALLER}.
      _RC=13
      exitCode
   fi
fi

if [ "${_USE_EXISTING}" == "0" ] ; then
   if [ ! -f ${_SCRIPTS_DIR}/${_TAR_GZ} ] ; then
      echo Failed to find tar.gz file ${_SCRIPTS_DIR}/${_TAR_GZ}
      _RC=14
      exitCode
   fi

   if [ -d "${_REPO_DIR}" ] ; then
      rm -f -r "${_REPO_DIR}"
   fi
fi

if [ "${_DEBUG}" == "1" ] ; then
   echo .
   echo _COMPONENT_DIR=${_COMPONENT_DIR}
   echo _SHARED_DIR=${_SHARED_DIR}
   echo .
fi 

echo Validating ${_REPO_DIR}/repository.config
if [ ! -f ${_REPO_DIR}/repository.config ] ; then
   # First ensure the downloaded .tar.gz exists
   if [ ! -f "${_SCRIPTS_DIR}/${_TAR_GZ}" ] ; then
      echo Can not find tar.gz file ${_SCRIPTS_DIR}/${_TAR_GZ}
      _RC=16
      exitCode
   fi

   if [ ! -d "${_REPO_DIR}" ] ; then
      mkdir "${_REPO_DIR}"
   fi

   # In Linux and AIX, the extract also extracts the enclosed .tar 
   echo Extracting ${_SCRIPTS_DIR}/${_TAR_GZ} to ${_REPO_DIR}
   ${_ZIP} --directory=${_REPO_DIR} -zxvlf ${_SCRIPTS_DIR}/${_TAR_GZ}
   _RC=$?

   if [ ${_RC} -gt ${_MAX_RC} ] ; then
      echo Failed to extract ${_SCRIPTS_DIR}/${_TAR_GZ} to ${_REPO_DIR}
      _RC=16
      exitCode
   fi

   # In Linux and AIX there shouldn't be a .tar file
   if [ -f "${_REPO_DIR}/${_TAR}" ] ; then
      echo Removing ${_REPO_DIR}/${_TAR}
      rm -f ${_REPO_DIR}/${_TAR}
   fi
fi


if [ ! -f ${_REPO_DIR}/repository.config ] ; then
   echo Error ${_REPO_DIR}/repository.config was not extracted!
   _RC=18
   exitCode
fi

#COPY_FILES
if [ "${_MERGE}" == "0" ] ; then
   for f in "${_FILE_LIST[@]}"
   do
      echo COPYING "${_SCRIPTS_DIR}/${f}" to "${_SHARED_DIR}/${f}"
      cp -f "${_SCRIPTS_DIR}/${f}" "${_SHARED_DIR}/${f}"
   done
fi
# Internal Use Only
if [ "${_SOA_COMPONENT}" == "java" ] ; then
   for f in "${_FILE_LIST_JAVA[@]}"
   do
      echo COPYING "${_SCRIPTS_DIR}/${f}" to "${_SHARED_DIR}/${f}"
      cp -f "${_SCRIPTS_DIR}/${f}" "${_SHARED_DIR}/${f}"
   done
fi

#REPLACE

# Because the string INSTALL_component= is present in UNINSTALL_component=
# We need to perform multiple steps
echo "Setting install uninstall state for all components to 0"
UNINSTALL_RUNTIME=0
INSTALL_RUNTIME=0
UNINSTALL_SHARED=0
INSTALL_SHARED=0

# Internal Use Only
UNINSTALL_TEST=0
INSTALL_TEST=0
UNINSTALL_JAVA=0
INSTALL_JAVA=0

if [ "${_UPDATE}" == "1" ] ; then
   _PERFORM=1
   if [ "${_SOA_COMPONENT}" == "runtime" ] ; then
      echo Only setting the INSTALL indicator for component ${_SOA_COMPONENT} in ${_SHARED_DIR}/SilentInstall.sh
      INSTALL_RUNTIME=1
   elif [ "${_SOA_COMPONENT}" == "test" ] ; then
      echo Only setting the INSTALL indicator for component ${_SOA_COMPONENT} in ${_SHARED_DIR}/SilentInstall.sh
      INSTALL_TEST=1
   else
      # All Shared components must be installed together
      echo Only setting the INSTALL indicator for package group shared in ${_SHARED_DIR}/SilentInstall.sh
      INSTALL_SHARED=1
   fi
elif [ "${_INSTALL}" == "1" ] ; then 
   _PERFORM=1
   echo Setting the INSTALL indicator for component ${_SOA_COMPONENT} in ${_SHARED_DIR}/SilentInstall.sh
   if [ "${_SOA_COMPONENT}" == "runtime" ] ; then
      UNINSTALL_RUNTIME=1
      INSTALL_RUNTIME=1
   elif [ "${_SOA_COMPONENT}" == "test" ] ; then
      UNINSTALL_TEST=1
      INSTALL_TEST=1
   elif [ "${_SOA_COMPONENT}" == "java" ] ; then
      UNINSTALL_JAVA=1
      INSTALL_JAVA=1
   else 
      # All Shared components must be installed together
      UNINSTALL_SHARED=1
      INSTALL_SHARED=1
   fi
elif [ "${_DELETE}" == "1" ] ; then 
   _PERFORM=1
   echo Only setting the UNINSTALL indicator for component ${_SOA_COMPONENT} in ${_SHARED_DIR}/SilentInstall.sh
   if [ "${_SOA_COMPONENT}" == "runtime" ] ; then
      UNINSTALL_RUNTIME=1
   elif [ "${_SOA_COMPONENT}" == "test" ] ; then
      UNINSTALL_TEST=1
   elif [ "${_SOA_COMPONENT}" == "java" ] ; then
      UNINSTALL_JAVA=1
   else 
      # All Shared components must be installed together
      UNINSTALL_SHARED=1
   fi
else
   _PERFORM=0
fi 
export INSTALL_RUNTIME UNINSTALL_RUNTIME INSTALL_SHARED UNINSTALL_SHARED
# Internal Use Only
export INSTALL_JAVA UNINSTALL_JAVA INSTALL_TEST UNINSTALL_TEST

if [ "${_PERFORM}." == "1." ] ; then
   cd "${_SHARED_DIR}"

   if [ ! -f ${_SHARED_DIR}/SilentInstall.sh ] ; then
      echo ${_SHARED_DIR}/SilentInstall.sh not found.
      _RC=18
      exitCode
   fi

   # Create a timestamp in the format YYYMMDD_HHSS
   TIME_STAMP=`date +%Y%m%d_%H%M`

   ConfigFiles=(OptimConfigClient OptimConfigServer)
   
   if [ "${_SOA_COMPONENT}" == "runtime" ] ; then  
      for theFile in ${ConfigFiles[@]}
         do
            # Backup the current file if one exits
            if [ -f ${OPTIM_ROOT}/rt/${theFile}.pst ] ; then
               echo cp ${OPTIM_ROOT}/rt/${theFile}.pst  ${_SCRIPTS_DIR}/${theFile}_${TIME_STAMP}.pst
               cp ${OPTIM_ROOT}/rt/${theFile}.pst  ${_SCRIPTS_DIR}/${theFile}_${TIME_STAMP}.pst
            fi
         done
   fi

   echo Calling the silent installer ${_SHARED_DIR}/SilentInstall.sh .... 
   sh ${_SHARED_DIR}/SilentInstall.sh
   _RC=$?
   if [ "${_SOA_COMPONENT}" == "runtime" ] ; then
      # Restore the backup OptimConfigClient file
      for theFile in ${ConfigFiles[@]}
         do
            # Restre the backup file if one exits
            if [ -f ${_SCRIPTS_DIR}/${theFile}_${TIME_STAMP}.pst ] ; then
               if [ -f ${OPTIM_ROOT}/rt/${theFile}.pst ] ; then
                  cd ${OPTIM_ROOT}/rt
                  mv ${OPTIM_ROOT}/rt/${theFile}.pst ${theFile}_${TIME_STAMP}_BAK.pst
               fi
               echo cp ${_SCRIPTS_DIR}/${theFile}_${TIME_STAMP}.pst ${OPTIM_ROOT}/rt/${theFile}.pst
               cp ${_SCRIPTS_DIR}/${theFile}_${TIME_STAMP}.pst ${OPTIM_ROOT}/rt/${theFile}.pst
            fi
         done
   fi

   if [ ${_RC} -gt ${_MAX_RC} ] ; then
      echo "${_SHARED_DIR}"/SilentInstall.sh failed.
      exitCode
   fi
fi

displayStatus
#DONE
exitScript